#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'oxygentabdemowidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENTABDEMOWIDGET_H
#define UI_OXYGENTABDEMOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"
#include "oxygentabwidget.h"

QT_BEGIN_NAMESPACE

class Ui_TabDemoWidget
{
public:
    QVBoxLayout *verticalLayout_5;
    QGridLayout *gridLayout;
    QLabel *label;
    KComboBox *tabPositionComboBox;
    QSpacerItem *horizontalSpacer;
    QLabel *label_2;
    KComboBox *textPositionComboBox;
    QCheckBox *documentModeCheckBox;
    QCheckBox *cornerWidgetsCheckBox;
    QCheckBox *tabCloseButtonsCheckBox;
    QCheckBox *tabBarVisibilityCheckBox;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    Oxygen::TabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout;
    KLineEdit *lineEdit;
    QTextEdit *textEdit;
    QWidget *tab_3;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_4;
    QSpacerItem *verticalSpacer;
    KLineEdit *lineEdit_2;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_2;
    QTextEdit *textEdit_2;

    void setupUi(QWidget *TabDemoWidget)
    {
        if (TabDemoWidget->objectName().isEmpty())
            TabDemoWidget->setObjectName(QString::fromUtf8("TabDemoWidget"));
        TabDemoWidget->resize(421, 420);
        verticalLayout_5 = new QVBoxLayout(TabDemoWidget);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(TabDemoWidget);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        tabPositionComboBox = new KComboBox(TabDemoWidget);
        tabPositionComboBox->addItem(QString());
        tabPositionComboBox->addItem(QString());
        tabPositionComboBox->addItem(QString());
        tabPositionComboBox->addItem(QString());
        tabPositionComboBox->setObjectName(QString::fromUtf8("tabPositionComboBox"));

        gridLayout->addWidget(tabPositionComboBox, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(261, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        label_2 = new QLabel(TabDemoWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        textPositionComboBox = new KComboBox(TabDemoWidget);
        textPositionComboBox->addItem(QString());
        textPositionComboBox->addItem(QString());
        textPositionComboBox->addItem(QString());
        textPositionComboBox->setObjectName(QString::fromUtf8("textPositionComboBox"));

        gridLayout->addWidget(textPositionComboBox, 1, 1, 1, 1);


        verticalLayout_5->addLayout(gridLayout);

        documentModeCheckBox = new QCheckBox(TabDemoWidget);
        documentModeCheckBox->setObjectName(QString::fromUtf8("documentModeCheckBox"));

        verticalLayout_5->addWidget(documentModeCheckBox);

        cornerWidgetsCheckBox = new QCheckBox(TabDemoWidget);
        cornerWidgetsCheckBox->setObjectName(QString::fromUtf8("cornerWidgetsCheckBox"));

        verticalLayout_5->addWidget(cornerWidgetsCheckBox);

        tabCloseButtonsCheckBox = new QCheckBox(TabDemoWidget);
        tabCloseButtonsCheckBox->setObjectName(QString::fromUtf8("tabCloseButtonsCheckBox"));

        verticalLayout_5->addWidget(tabCloseButtonsCheckBox);

        tabBarVisibilityCheckBox = new QCheckBox(TabDemoWidget);
        tabBarVisibilityCheckBox->setObjectName(QString::fromUtf8("tabBarVisibilityCheckBox"));

        verticalLayout_5->addWidget(tabBarVisibilityCheckBox);

        groupBox = new QGroupBox(TabDemoWidget);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        verticalLayout_3->setContentsMargins(4, 4, 4, 4);
        tabWidget = new Oxygen::TabWidget(groupBox);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabWidget->setTabPosition(QTabWidget::North);
        tabWidget->setDocumentMode(false);
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        verticalLayout = new QVBoxLayout(tab);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        lineEdit = new KLineEdit(tab);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setProperty("showClearButton", QVariant(true));

        verticalLayout->addWidget(lineEdit);

        textEdit = new QTextEdit(tab);
        textEdit->setObjectName(QString::fromUtf8("textEdit"));

        verticalLayout->addWidget(textEdit);

        tabWidget->addTab(tab, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName(QString::fromUtf8("tab_3"));
        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName(QString::fromUtf8("tab_4"));
        verticalLayout_4 = new QVBoxLayout(tab_4);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        lineEdit_2 = new KLineEdit(tab_4);
        lineEdit_2->setObjectName(QString::fromUtf8("lineEdit_2"));
        lineEdit_2->setProperty("showClearButton", QVariant(true));

        verticalLayout_4->addWidget(lineEdit_2);

        tabWidget->addTab(tab_4, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QString::fromUtf8("tab_2"));
        verticalLayout_2 = new QVBoxLayout(tab_2);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        textEdit_2 = new QTextEdit(tab_2);
        textEdit_2->setObjectName(QString::fromUtf8("textEdit_2"));
        textEdit_2->setFrameShape(QFrame::NoFrame);

        verticalLayout_2->addWidget(textEdit_2);

        tabWidget->addTab(tab_2, QString());

        verticalLayout_3->addWidget(tabWidget);


        verticalLayout_5->addWidget(groupBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(tabPositionComboBox);
        label_2->setBuddy(textPositionComboBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(tabPositionComboBox, textPositionComboBox);
        QWidget::setTabOrder(textPositionComboBox, documentModeCheckBox);
        QWidget::setTabOrder(documentModeCheckBox, cornerWidgetsCheckBox);
        QWidget::setTabOrder(cornerWidgetsCheckBox, tabCloseButtonsCheckBox);
        QWidget::setTabOrder(tabCloseButtonsCheckBox, tabBarVisibilityCheckBox);
        QWidget::setTabOrder(tabBarVisibilityCheckBox, tabWidget);
        QWidget::setTabOrder(tabWidget, lineEdit);
        QWidget::setTabOrder(lineEdit, textEdit);
        QWidget::setTabOrder(textEdit, lineEdit_2);
        QWidget::setTabOrder(lineEdit_2, textEdit_2);

        retranslateUi(TabDemoWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(TabDemoWidget);
    } // setupUi

    void retranslateUi(QWidget *TabDemoWidget)
    {
        label->setText(tr2i18n("&Tab position:", nullptr));
        tabPositionComboBox->setItemText(0, tr2i18n("North", nullptr));
        tabPositionComboBox->setItemText(1, tr2i18n("South", nullptr));
        tabPositionComboBox->setItemText(2, tr2i18n("West", nullptr));
        tabPositionComboBox->setItemText(3, tr2i18n("East", nullptr));

        label_2->setText(tr2i18n("Te&xt position:", nullptr));
        textPositionComboBox->setItemText(0, tr2i18n("Icons Only", nullptr));
        textPositionComboBox->setItemText(1, tr2i18n("Text Only", nullptr));
        textPositionComboBox->setItemText(2, tr2i18n("Text Alongside Icons", nullptr));

        documentModeCheckBox->setText(tr2i18n("Document mode", nullptr));
        cornerWidgetsCheckBox->setText(tr2i18n("Show Corner Buttons", nullptr));
        tabCloseButtonsCheckBox->setText(tr2i18n("Show Tab Close Buttons", nullptr));
        tabBarVisibilityCheckBox->setText(tr2i18n("Hide tabbar", nullptr));
        groupBox->setTitle(tr2i18n("Preview", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_4), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QString());
        (void)TabDemoWidget;
    } // retranslateUi

};

namespace Ui {
    class TabDemoWidget: public Ui_TabDemoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENTABDEMOWIDGET_H

