#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'oxygenbenchmarkwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENBENCHMARKWIDGET_H
#define UI_OXYGENBENCHMARKWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BenchmarkWidget
{
public:
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *grabMouseCheckBox;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *runButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *BenchmarkWidget)
    {
        if (BenchmarkWidget->objectName().isEmpty())
            BenchmarkWidget->setObjectName(QString::fromUtf8("BenchmarkWidget"));
        BenchmarkWidget->resize(407, 300);
        verticalLayout_4 = new QVBoxLayout(BenchmarkWidget);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(BenchmarkWidget);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        verticalLayout_3->addWidget(label);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));

        verticalLayout_3->addLayout(verticalLayout);


        verticalLayout_4->addWidget(groupBox);

        groupBox_2 = new QGroupBox(BenchmarkWidget);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        grabMouseCheckBox = new QCheckBox(groupBox_2);
        grabMouseCheckBox->setObjectName(QString::fromUtf8("grabMouseCheckBox"));
        grabMouseCheckBox->setChecked(true);

        verticalLayout_2->addWidget(grabMouseCheckBox);


        verticalLayout_4->addWidget(groupBox_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        runButton = new QPushButton(BenchmarkWidget);
        runButton->setObjectName(QString::fromUtf8("runButton"));

        horizontalLayout->addWidget(runButton);


        verticalLayout_4->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);


        retranslateUi(BenchmarkWidget);

        QMetaObject::connectSlotsByName(BenchmarkWidget);
    } // setupUi

    void retranslateUi(QWidget *BenchmarkWidget)
    {
        groupBox->setTitle(tr2i18n("Modules", nullptr));
        label->setText(tr2i18n("Select below the modules for which you want to run the simulation:", nullptr));
        groupBox_2->setTitle(tr2i18n("Options", nullptr));
        grabMouseCheckBox->setText(tr2i18n("Grab mouse", nullptr));
        runButton->setText(tr2i18n("Run Simulation", nullptr));
        (void)BenchmarkWidget;
    } // retranslateUi

};

namespace Ui {
    class BenchmarkWidget: public Ui_BenchmarkWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENBENCHMARKWIDGET_H

