// This file is generated by kconfig_compiler_kf6 from oxygeninactiveshadowconfigdata.kcfg.
// All changes you do to this file will be lost.

#include "oxygeninactiveshadowconfiguration.h"

#include <qglobal.h>
#include <QFile>

using namespace Oxygen;

namespace Oxygen {

class InactiveShadowConfigurationHelper
{
  public:
    InactiveShadowConfigurationHelper() : q(nullptr) {}
    ~InactiveShadowConfigurationHelper() { delete q; q = nullptr; }
    InactiveShadowConfigurationHelper(const InactiveShadowConfigurationHelper&) = delete;
    InactiveShadowConfigurationHelper& operator=(const InactiveShadowConfigurationHelper&) = delete;
    InactiveShadowConfiguration *q;
};

}
Q_GLOBAL_STATIC(InactiveShadowConfigurationHelper, s_globalInactiveShadowConfiguration)
InactiveShadowConfiguration *InactiveShadowConfiguration::self()
{
  if (!s_globalInactiveShadowConfiguration()->q) {
    new InactiveShadowConfiguration;
    s_globalInactiveShadowConfiguration()->q->read();
  }

  return s_globalInactiveShadowConfiguration()->q;
}

InactiveShadowConfiguration::InactiveShadowConfiguration( )
  : KConfigSkeleton( QStringLiteral( "oxygenrc" ) )
{
  Q_ASSERT(!s_globalInactiveShadowConfiguration()->q);
  s_globalInactiveShadowConfiguration()->q = this;
  setCurrentGroup( QStringLiteral( "InactiveShadow" ) );

  KConfigSkeleton::ItemBool  *itemEnabled;
  itemEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Enabled" ), mEnabled, true );
  addItem( itemEnabled, QStringLiteral( "Enabled" ) );
  KConfigSkeleton::ItemInt  *itemShadowSize;
  itemShadowSize = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ShadowSize" ), mShadowSize, 40 );
  addItem( itemShadowSize, QStringLiteral( "ShadowSize" ) );
  KConfigSkeleton::ItemDouble  *itemVerticalOffset;
  itemVerticalOffset = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "VerticalOffset" ), mVerticalOffset, 0.2 );
  addItem( itemVerticalOffset, QStringLiteral( "VerticalOffset" ) );
  KConfigSkeleton::ItemColor  *itemInnerColor;
  itemInnerColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "InnerColor" ), mInnerColor, QColor( 0, 0, 0 ) );
  addItem( itemInnerColor, QStringLiteral( "InnerColor" ) );
  KConfigSkeleton::ItemColor  *itemOuterColor;
  itemOuterColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "OuterColor" ), mOuterColor, QColor( 0, 0, 0 ) );
  addItem( itemOuterColor, QStringLiteral( "OuterColor" ) );
  KConfigSkeleton::ItemBool  *itemUseOuterColor;
  itemUseOuterColor = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseOuterColor" ), mUseOuterColor, false );
  addItem( itemUseOuterColor, QStringLiteral( "UseOuterColor" ) );
}

InactiveShadowConfiguration::~InactiveShadowConfiguration()
{
  if (s_globalInactiveShadowConfiguration.exists() && !s_globalInactiveShadowConfiguration.isDestroyed()) {
    s_globalInactiveShadowConfiguration()->q = nullptr;
  }
}

