/********************************************************************************
** Form generated from reading UI file 'oxygenexceptionlistwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENEXCEPTIONLISTWIDGET_H
#define UI_OXYGENEXCEPTIONLISTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OxygenExceptionListWidget
{
public:
    QGridLayout *gridLayout;
    QTreeView *exceptionListView;
    QSpacerItem *verticalSpacer;
    QPushButton *moveUpButton;
    QPushButton *moveDownButton;
    QPushButton *addButton;
    QPushButton *removeButton;
    QPushButton *editButton;

    void setupUi(QWidget *OxygenExceptionListWidget)
    {
        if (OxygenExceptionListWidget->objectName().isEmpty())
            OxygenExceptionListWidget->setObjectName("OxygenExceptionListWidget");
        OxygenExceptionListWidget->resize(473, 163);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OxygenExceptionListWidget->sizePolicy().hasHeightForWidth());
        OxygenExceptionListWidget->setSizePolicy(sizePolicy);
        OxygenExceptionListWidget->setMinimumSize(QSize(0, 0));
        gridLayout = new QGridLayout(OxygenExceptionListWidget);
        gridLayout->setObjectName("gridLayout");
        exceptionListView = new QTreeView(OxygenExceptionListWidget);
        exceptionListView->setObjectName("exceptionListView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(exceptionListView->sizePolicy().hasHeightForWidth());
        exceptionListView->setSizePolicy(sizePolicy1);
        exceptionListView->setMinimumSize(QSize(100, 100));

        gridLayout->addWidget(exceptionListView, 0, 0, 6, 1);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 5, 1, 1, 1);

        moveUpButton = new QPushButton(OxygenExceptionListWidget);
        moveUpButton->setObjectName("moveUpButton");

        gridLayout->addWidget(moveUpButton, 0, 1, 1, 1);

        moveDownButton = new QPushButton(OxygenExceptionListWidget);
        moveDownButton->setObjectName("moveDownButton");

        gridLayout->addWidget(moveDownButton, 1, 1, 1, 1);

        addButton = new QPushButton(OxygenExceptionListWidget);
        addButton->setObjectName("addButton");

        gridLayout->addWidget(addButton, 2, 1, 1, 1);

        removeButton = new QPushButton(OxygenExceptionListWidget);
        removeButton->setObjectName("removeButton");

        gridLayout->addWidget(removeButton, 3, 1, 1, 1);

        editButton = new QPushButton(OxygenExceptionListWidget);
        editButton->setObjectName("editButton");

        gridLayout->addWidget(editButton, 4, 1, 1, 1);

        QWidget::setTabOrder(exceptionListView, moveUpButton);
        QWidget::setTabOrder(moveUpButton, moveDownButton);
        QWidget::setTabOrder(moveDownButton, addButton);
        QWidget::setTabOrder(addButton, removeButton);
        QWidget::setTabOrder(removeButton, editButton);

        retranslateUi(OxygenExceptionListWidget);

        QMetaObject::connectSlotsByName(OxygenExceptionListWidget);
    } // setupUi

    void retranslateUi(QWidget *OxygenExceptionListWidget)
    {
        moveUpButton->setText(tr2i18n("Move Up", nullptr));
        moveDownButton->setText(tr2i18n("Move Down", nullptr));
        addButton->setText(tr2i18n("Add", nullptr));
        removeButton->setText(tr2i18n("Remove", nullptr));
        editButton->setText(tr2i18n("Edit", nullptr));
        (void)OxygenExceptionListWidget;
    } // retranslateUi

};

namespace Ui {
    class OxygenExceptionListWidget: public Ui_OxygenExceptionListWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENEXCEPTIONLISTWIDGET_H

