/********************************************************************************
** Form generated from reading UI file 'oxygenstyleconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENSTYLECONFIG_H
#define UI_OXYGENSTYLECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "oxygenanimationconfigwidget.h"

QT_BEGIN_NAMESPACE

class Ui_OxygenStyleConfig
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab_1;
    QGridLayout *gridLayout;
    KComboBox *_windowDragMode;
    QLabel *_mnemonicsLabel;
    KComboBox *_mnemonicsMode;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer_4;
    QCheckBox *_toolBarDrawItemSeparator;
    QCheckBox *_splitterProxyEnabled;
    QCheckBox *_useBackgroundGradient;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab;
    QVBoxLayout *verticalLayout_4;
    Oxygen::AnimationConfigWidget *_animationConfigWidget;
    QWidget *tab_2;
    QGridLayout *gridLayout_5;
    QCheckBox *_viewDrawTreeBranchLines;
    QWidget *_viewsExpertWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    KComboBox *_viewTriangularExpanderSize;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *_viewDrawFocusIndicator;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    QSlider *_scrollBarWidthSlider;
    QSpinBox *_scrollBarWidth;
    QSpacerItem *horizontalSpacer_2;
    QGridLayout *gridLayout_4;
    QLabel *label_5;
    QLabel *label_6;
    KComboBox *_scrollBarSubLineButtons;
    QSpacerItem *horizontalSpacer;
    KComboBox *_scrollBarAddLineButtons;
    QSpacerItem *verticalSpacer;
    QWidget *tab_5;
    QGridLayout *gridLayout_3;
    QRadioButton *_menuHighlightDark;
    QRadioButton *_menuHighlightStrong;
    QRadioButton *_menuHighlightSubtle;
    QSpacerItem *verticalSpacer_5;

    void setupUi(QWidget *OxygenStyleConfig)
    {
        if (OxygenStyleConfig->objectName().isEmpty())
            OxygenStyleConfig->setObjectName("OxygenStyleConfig");
        OxygenStyleConfig->resize(450, 250);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(OxygenStyleConfig->sizePolicy().hasHeightForWidth());
        OxygenStyleConfig->setSizePolicy(sizePolicy);
        OxygenStyleConfig->setMinimumSize(QSize(450, 200));
        verticalLayout = new QVBoxLayout(OxygenStyleConfig);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(OxygenStyleConfig);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy1);
        tab_1 = new QWidget();
        tab_1->setObjectName("tab_1");
        gridLayout = new QGridLayout(tab_1);
        gridLayout->setObjectName("gridLayout");
        _windowDragMode = new KComboBox(tab_1);
        _windowDragMode->addItem(QString());
        _windowDragMode->addItem(QString());
        _windowDragMode->addItem(QString());
        _windowDragMode->setObjectName("_windowDragMode");

        gridLayout->addWidget(_windowDragMode, 4, 1, 1, 1);

        _mnemonicsLabel = new QLabel(tab_1);
        _mnemonicsLabel->setObjectName("_mnemonicsLabel");
        _mnemonicsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(_mnemonicsLabel, 3, 0, 1, 1);

        _mnemonicsMode = new KComboBox(tab_1);
        _mnemonicsMode->addItem(QString());
        _mnemonicsMode->addItem(QString());
        _mnemonicsMode->addItem(QString());
        _mnemonicsMode->setObjectName("_mnemonicsMode");

        gridLayout->addWidget(_mnemonicsMode, 3, 1, 1, 1);

        label_3 = new QLabel(tab_1);
        label_3->setObjectName("label_3");
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 4, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 3, 2, 1, 1);

        _toolBarDrawItemSeparator = new QCheckBox(tab_1);
        _toolBarDrawItemSeparator->setObjectName("_toolBarDrawItemSeparator");

        gridLayout->addWidget(_toolBarDrawItemSeparator, 1, 0, 1, 3);

        _splitterProxyEnabled = new QCheckBox(tab_1);
        _splitterProxyEnabled->setObjectName("_splitterProxyEnabled");

        gridLayout->addWidget(_splitterProxyEnabled, 2, 0, 1, 3);

        _useBackgroundGradient = new QCheckBox(tab_1);
        _useBackgroundGradient->setObjectName("_useBackgroundGradient");

        gridLayout->addWidget(_useBackgroundGradient, 0, 0, 1, 3);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 5, 0, 1, 3);

        gridLayout->setColumnStretch(2, 1);
        tabWidget->addTab(tab_1, QString());
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_4 = new QVBoxLayout(tab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        _animationConfigWidget = new Oxygen::AnimationConfigWidget(tab);
        _animationConfigWidget->setObjectName("_animationConfigWidget");

        verticalLayout_4->addWidget(_animationConfigWidget);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_5 = new QGridLayout(tab_2);
        gridLayout_5->setObjectName("gridLayout_5");
        _viewDrawTreeBranchLines = new QCheckBox(tab_2);
        _viewDrawTreeBranchLines->setObjectName("_viewDrawTreeBranchLines");

        gridLayout_5->addWidget(_viewDrawTreeBranchLines, 1, 0, 1, 2);

        _viewsExpertWidget = new QWidget(tab_2);
        _viewsExpertWidget->setObjectName("_viewsExpertWidget");
        horizontalLayout = new QHBoxLayout(_viewsExpertWidget);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        label_4 = new QLabel(_viewsExpertWidget);
        label_4->setObjectName("label_4");

        horizontalLayout->addWidget(label_4);

        _viewTriangularExpanderSize = new KComboBox(_viewsExpertWidget);
        _viewTriangularExpanderSize->addItem(QString());
        _viewTriangularExpanderSize->addItem(QString());
        _viewTriangularExpanderSize->addItem(QString());
        _viewTriangularExpanderSize->setObjectName("_viewTriangularExpanderSize");

        horizontalLayout->addWidget(_viewTriangularExpanderSize);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        gridLayout_5->addWidget(_viewsExpertWidget, 2, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(259, 70, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_3, 3, 0, 1, 2);

        _viewDrawFocusIndicator = new QCheckBox(tab_2);
        _viewDrawFocusIndicator->setObjectName("_viewDrawFocusIndicator");

        gridLayout_5->addWidget(_viewDrawFocusIndicator, 0, 0, 1, 2);

        tabWidget->addTab(tab_2, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout_2 = new QVBoxLayout(tab_4);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label = new QLabel(tab_4);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(label);

        _scrollBarWidthSlider = new QSlider(tab_4);
        _scrollBarWidthSlider->setObjectName("_scrollBarWidthSlider");
        _scrollBarWidthSlider->setMinimum(10);
        _scrollBarWidthSlider->setMaximum(30);
        _scrollBarWidthSlider->setPageStep(5);
        _scrollBarWidthSlider->setOrientation(Qt::Horizontal);
        _scrollBarWidthSlider->setTickPosition(QSlider::TicksBelow);
        _scrollBarWidthSlider->setTickInterval(5);

        horizontalLayout_3->addWidget(_scrollBarWidthSlider);

        _scrollBarWidth = new QSpinBox(tab_4);
        _scrollBarWidth->setObjectName("_scrollBarWidth");
        _scrollBarWidth->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        _scrollBarWidth->setMinimum(10);
        _scrollBarWidth->setMaximum(30);

        horizontalLayout_3->addWidget(_scrollBarWidth);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_3);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        label_5 = new QLabel(tab_4);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(label_5, 0, 0, 1, 1);

        label_6 = new QLabel(tab_4);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(label_6, 1, 0, 1, 1);

        _scrollBarSubLineButtons = new KComboBox(tab_4);
        _scrollBarSubLineButtons->addItem(QString());
        _scrollBarSubLineButtons->addItem(QString());
        _scrollBarSubLineButtons->addItem(QString());
        _scrollBarSubLineButtons->setObjectName("_scrollBarSubLineButtons");

        gridLayout_4->addWidget(_scrollBarSubLineButtons, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 2, 1, 1);

        _scrollBarAddLineButtons = new KComboBox(tab_4);
        _scrollBarAddLineButtons->addItem(QString());
        _scrollBarAddLineButtons->addItem(QString());
        _scrollBarAddLineButtons->addItem(QString());
        _scrollBarAddLineButtons->setObjectName("_scrollBarAddLineButtons");

        gridLayout_4->addWidget(_scrollBarAddLineButtons, 1, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        tabWidget->addTab(tab_4, QString());
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        gridLayout_3 = new QGridLayout(tab_5);
        gridLayout_3->setObjectName("gridLayout_3");
        _menuHighlightDark = new QRadioButton(tab_5);
        _menuHighlightDark->setObjectName("_menuHighlightDark");

        gridLayout_3->addWidget(_menuHighlightDark, 0, 0, 1, 1);

        _menuHighlightStrong = new QRadioButton(tab_5);
        _menuHighlightStrong->setObjectName("_menuHighlightStrong");

        gridLayout_3->addWidget(_menuHighlightStrong, 1, 0, 1, 1);

        _menuHighlightSubtle = new QRadioButton(tab_5);
        _menuHighlightSubtle->setObjectName("_menuHighlightSubtle");

        gridLayout_3->addWidget(_menuHighlightSubtle, 2, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_5, 3, 0, 1, 1);

        tabWidget->addTab(tab_5, QString());

        verticalLayout->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        _mnemonicsLabel->setBuddy(_mnemonicsMode);
        label_3->setBuddy(_windowDragMode);
        label_4->setBuddy(_viewTriangularExpanderSize);
        label->setBuddy(_scrollBarWidthSlider);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(tabWidget, _useBackgroundGradient);
        QWidget::setTabOrder(_useBackgroundGradient, _toolBarDrawItemSeparator);
        QWidget::setTabOrder(_toolBarDrawItemSeparator, _splitterProxyEnabled);
        QWidget::setTabOrder(_splitterProxyEnabled, _mnemonicsMode);
        QWidget::setTabOrder(_mnemonicsMode, _windowDragMode);
        QWidget::setTabOrder(_windowDragMode, _viewDrawFocusIndicator);
        QWidget::setTabOrder(_viewDrawFocusIndicator, _viewDrawTreeBranchLines);
        QWidget::setTabOrder(_viewDrawTreeBranchLines, _viewTriangularExpanderSize);
        QWidget::setTabOrder(_viewTriangularExpanderSize, _scrollBarWidthSlider);
        QWidget::setTabOrder(_scrollBarWidthSlider, _scrollBarWidth);
        QWidget::setTabOrder(_scrollBarWidth, _scrollBarSubLineButtons);
        QWidget::setTabOrder(_scrollBarSubLineButtons, _scrollBarAddLineButtons);
        QWidget::setTabOrder(_scrollBarAddLineButtons, _menuHighlightDark);
        QWidget::setTabOrder(_menuHighlightDark, _menuHighlightStrong);
        QWidget::setTabOrder(_menuHighlightStrong, _menuHighlightSubtle);

        retranslateUi(OxygenStyleConfig);
        QObject::connect(_scrollBarWidth, &QSpinBox::valueChanged, _scrollBarWidthSlider, &QSlider::setValue);
        QObject::connect(_scrollBarWidthSlider, &QSlider::valueChanged, _scrollBarWidth, &QSpinBox::setValue);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OxygenStyleConfig);
    } // setupUi

    void retranslateUi(QWidget *OxygenStyleConfig)
    {
        OxygenStyleConfig->setWindowTitle(tr2i18n("Dialog", nullptr));
        _windowDragMode->setItemText(0, tr2i18n("Drag windows from titlebar only", nullptr));
        _windowDragMode->setItemText(1, tr2i18n("Drag windows from titlebar, menubar and toolbars", nullptr));
        _windowDragMode->setItemText(2, tr2i18n("Drag windows from all empty areas", nullptr));

        _mnemonicsLabel->setText(tr2i18n("Keyboard accelerators visibility:", nullptr));
        _mnemonicsMode->setItemText(0, tr2i18n("Always hide", nullptr));
        _mnemonicsMode->setItemText(1, tr2i18n("Show when Alt key is pressed", nullptr));
        _mnemonicsMode->setItemText(2, tr2i18n("Always show", nullptr));

        label_3->setText(tr2i18n("Windows' &drag mode:", nullptr));
        _toolBarDrawItemSeparator->setText(tr2i18n("Draw toolbar item separators", nullptr));
        _splitterProxyEnabled->setText(tr2i18n("Enable extended resize handles", nullptr));
        _useBackgroundGradient->setText(tr2i18n("Draw window background gradient", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_1), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Animations", nullptr));
        _viewDrawTreeBranchLines->setText(tr2i18n("Draw tree branch lines", nullptr));
        label_4->setText(tr2i18n("&Tree expander size:", nullptr));
        _viewTriangularExpanderSize->setItemText(0, tr2i18n("Tiny", "triangle size"));
        _viewTriangularExpanderSize->setItemText(1, tr2i18n("Small", "triangle size"));
        _viewTriangularExpanderSize->setItemText(2, tr2i18n("Normal", "triangle size"));

        _viewDrawFocusIndicator->setText(tr2i18n("Draw focus indicator in lists", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Views", nullptr));
        label->setText(tr2i18n("Scrollbar wi&dth:", nullptr));
        _scrollBarWidth->setSuffix(tr2i18n("px", nullptr));
        label_5->setText(tr2i18n("Top arrow button type:", nullptr));
        label_6->setText(tr2i18n("Bottom arrow button type:", nullptr));
        _scrollBarSubLineButtons->setItemText(0, tr2i18n("No buttons", nullptr));
        _scrollBarSubLineButtons->setItemText(1, tr2i18n("One button", nullptr));
        _scrollBarSubLineButtons->setItemText(2, tr2i18n("Two buttons", nullptr));

        _scrollBarAddLineButtons->setItemText(0, tr2i18n("No button", nullptr));
        _scrollBarAddLineButtons->setItemText(1, tr2i18n("One button", nullptr));
        _scrollBarAddLineButtons->setItemText(2, tr2i18n("Two buttons", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Scrollbars", nullptr));
        _menuHighlightDark->setText(tr2i18n("Use dar&k color", nullptr));
        _menuHighlightStrong->setText(tr2i18n("&Use selection color (plain)", nullptr));
        _menuHighlightSubtle->setText(tr2i18n("Use selec&tion color (subtle)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_5), tr2i18n("Menu Highlight", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OxygenStyleConfig: public Ui_OxygenStyleConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENSTYLECONFIG_H

