/********************************************************************************
** Form generated from reading UI file 'oxygenshadowconfigurationui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENSHADOWCONFIGURATIONUI_H
#define UI_OXYGENSHADOWCONFIGURATIONUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ShadowConfiguraionUI
{
public:
    QGridLayout *gridLayout;
    QLabel *label_3;
    KColorButton *innerColor;
    QLabel *label_4;
    KColorButton *outerColor;
    QCheckBox *useOuterColor;
    QLabel *label_2;
    QLabel *label;
    QSpinBox *shadowSize;
    QSpinBox *verticalOffset;

    void setupUi(QWidget *ShadowConfiguraionUI)
    {
        if (ShadowConfiguraionUI->objectName().isEmpty())
            ShadowConfiguraionUI->setObjectName("ShadowConfiguraionUI");
        ShadowConfiguraionUI->resize(180, 112);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ShadowConfiguraionUI->sizePolicy().hasHeightForWidth());
        ShadowConfiguraionUI->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(ShadowConfiguraionUI);
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(ShadowConfiguraionUI);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        innerColor = new KColorButton(ShadowConfiguraionUI);
        innerColor->setObjectName("innerColor");

        gridLayout->addWidget(innerColor, 2, 1, 1, 1);

        label_4 = new QLabel(ShadowConfiguraionUI);
        label_4->setObjectName("label_4");
        label_4->setEnabled(true);
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        outerColor = new KColorButton(ShadowConfiguraionUI);
        outerColor->setObjectName("outerColor");
        outerColor->setEnabled(false);

        gridLayout->addWidget(outerColor, 3, 1, 1, 1);

        useOuterColor = new QCheckBox(ShadowConfiguraionUI);
        useOuterColor->setObjectName("useOuterColor");

        gridLayout->addWidget(useOuterColor, 3, 2, 1, 1);

        label_2 = new QLabel(ShadowConfiguraionUI);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        label = new QLabel(ShadowConfiguraionUI);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        shadowSize = new QSpinBox(ShadowConfiguraionUI);
        shadowSize->setObjectName("shadowSize");

        gridLayout->addWidget(shadowSize, 0, 1, 1, 1);

        verticalOffset = new QSpinBox(ShadowConfiguraionUI);
        verticalOffset->setObjectName("verticalOffset");

        gridLayout->addWidget(verticalOffset, 1, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(innerColor);
        label_4->setBuddy(outerColor);
        label_2->setBuddy(verticalOffset);
        label->setBuddy(shadowSize);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(shadowSize, verticalOffset);
        QWidget::setTabOrder(verticalOffset, innerColor);
        QWidget::setTabOrder(innerColor, outerColor);
        QWidget::setTabOrder(outerColor, useOuterColor);

        retranslateUi(ShadowConfiguraionUI);
        QObject::connect(useOuterColor, SIGNAL(toggled(bool)), outerColor, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ShadowConfiguraionUI);
    } // setupUi

    void retranslateUi(QWidget *ShadowConfiguraionUI)
    {
        label_3->setText(tr2i18n("Inner Color:", nullptr));
        label_4->setText(tr2i18n("Outer Color:", nullptr));
        useOuterColor->setText(QString());
        label_2->setText(tr2i18n("Vertical Offset:", nullptr));
        label->setText(tr2i18n("Size: ", nullptr));
        shadowSize->setSuffix(tr2i18n("px", nullptr));
        verticalOffset->setSuffix(tr2i18n("px", nullptr));
        (void)ShadowConfiguraionUI;
    } // retranslateUi

};

namespace Ui {
    class ShadowConfiguraionUI: public Ui_ShadowConfiguraionUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENSHADOWCONFIGURATIONUI_H

