#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'oxygenbuttondemowidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENBUTTONDEMOWIDGET_H
#define UI_OXYGENBUTTONDEMOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ButtonDemoWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QCheckBox *checkBox;
    QCheckBox *checkBox_2;
    QCheckBox *checkBox_3;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBox_4;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *radioButton;
    QRadioButton *radioButton_2;
    QRadioButton *radioButton_3;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_4;
    QLabel *label_7;
    KComboBox *kcombobox;
    QSpacerItem *horizontalSpacer;
    QLabel *label_8;
    QCheckBox *flatButtonCheckBox;
    KComboBox *kcombobox_2;
    QToolButton *toolButton;
    QToolButton *toolButton_2;
    QPushButton *pushButton;
    QPushButton *pushButton_2;
    QPushButton *pushButton_3;
    QPushButton *pushButton_4;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QWidget *widget;
    QGridLayout *gridLayout_2;
    QToolButton *toolButton_3;
    QToolButton *toolButton_4;
    QToolButton *toolButton_5;
    QFrame *frame_2;
    QWidget *toolBarContainer;
    QToolButton *toolButton_6;
    QToolButton *toolButton_7;
    QToolButton *toolButton_8;
    QToolButton *toolButton_9;
    QToolButton *toolButton_10;
    QToolButton *toolButton_11;
    QToolButton *toolButton_12;
    QLabel *label_11;
    KComboBox *textPosition;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_12;
    KComboBox *iconSize;

    void setupUi(QWidget *ButtonDemoWidget)
    {
        if (ButtonDemoWidget->objectName().isEmpty())
            ButtonDemoWidget->setObjectName(QString::fromUtf8("ButtonDemoWidget"));
        ButtonDemoWidget->resize(412, 410);
        gridLayout = new QGridLayout(ButtonDemoWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        groupBox_3 = new QGroupBox(ButtonDemoWidget);
        groupBox_3->setObjectName(QString::fromUtf8("groupBox_3"));
        horizontalLayout = new QHBoxLayout(groupBox_3);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        checkBox = new QCheckBox(groupBox_3);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));

        verticalLayout->addWidget(checkBox);

        checkBox_2 = new QCheckBox(groupBox_3);
        checkBox_2->setObjectName(QString::fromUtf8("checkBox_2"));
        checkBox_2->setTristate(true);

        verticalLayout->addWidget(checkBox_2);

        checkBox_3 = new QCheckBox(groupBox_3);
        checkBox_3->setObjectName(QString::fromUtf8("checkBox_3"));
        checkBox_3->setChecked(true);

        verticalLayout->addWidget(checkBox_3);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout->addWidget(groupBox_3, 2, 0, 1, 1);

        groupBox_4 = new QGroupBox(ButtonDemoWidget);
        groupBox_4->setObjectName(QString::fromUtf8("groupBox_4"));
        horizontalLayout_2 = new QHBoxLayout(groupBox_4);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        radioButton = new QRadioButton(groupBox_4);
        radioButton->setObjectName(QString::fromUtf8("radioButton"));
        radioButton->setEnabled(true);
        radioButton->setChecked(true);

        verticalLayout_2->addWidget(radioButton);

        radioButton_2 = new QRadioButton(groupBox_4);
        radioButton_2->setObjectName(QString::fromUtf8("radioButton_2"));

        verticalLayout_2->addWidget(radioButton_2);

        radioButton_3 = new QRadioButton(groupBox_4);
        radioButton_3->setObjectName(QString::fromUtf8("radioButton_3"));

        verticalLayout_2->addWidget(radioButton_3);


        horizontalLayout_2->addLayout(verticalLayout_2);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        gridLayout->addWidget(groupBox_4, 2, 1, 1, 1);

        groupBox = new QGroupBox(ButtonDemoWidget);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_4 = new QGridLayout(groupBox);
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        label_7 = new QLabel(groupBox);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(label_7, 0, 0, 1, 1);

        kcombobox = new KComboBox(groupBox);
        kcombobox->addItem(QString());
        kcombobox->addItem(QString());
        kcombobox->addItem(QString());
        kcombobox->setObjectName(QString::fromUtf8("kcombobox"));

        gridLayout_4->addWidget(kcombobox, 0, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(36, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 0, 6, 1, 1);

        label_8 = new QLabel(groupBox);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_4->addWidget(label_8, 1, 0, 1, 1);

        flatButtonCheckBox = new QCheckBox(groupBox);
        flatButtonCheckBox->setObjectName(QString::fromUtf8("flatButtonCheckBox"));

        gridLayout_4->addWidget(flatButtonCheckBox, 2, 0, 1, 2);

        kcombobox_2 = new KComboBox(groupBox);
        kcombobox_2->setObjectName(QString::fromUtf8("kcombobox_2"));

        gridLayout_4->addWidget(kcombobox_2, 1, 4, 1, 1);

        toolButton = new QToolButton(groupBox);
        toolButton->setObjectName(QString::fromUtf8("toolButton"));

        gridLayout_4->addWidget(toolButton, 0, 5, 1, 1);

        toolButton_2 = new QToolButton(groupBox);
        toolButton_2->setObjectName(QString::fromUtf8("toolButton_2"));

        gridLayout_4->addWidget(toolButton_2, 1, 5, 1, 1);

        pushButton = new QPushButton(groupBox);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));

        gridLayout_4->addWidget(pushButton, 0, 1, 1, 1);

        pushButton_2 = new QPushButton(groupBox);
        pushButton_2->setObjectName(QString::fromUtf8("pushButton_2"));

        gridLayout_4->addWidget(pushButton_2, 0, 2, 1, 1);

        pushButton_3 = new QPushButton(groupBox);
        pushButton_3->setObjectName(QString::fromUtf8("pushButton_3"));

        gridLayout_4->addWidget(pushButton_3, 1, 1, 1, 1);

        pushButton_4 = new QPushButton(groupBox);
        pushButton_4->setObjectName(QString::fromUtf8("pushButton_4"));

        gridLayout_4->addWidget(pushButton_4, 1, 2, 1, 1);


        gridLayout->addWidget(groupBox, 0, 0, 1, 2);

        groupBox_2 = new QGroupBox(ButtonDemoWidget);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        widget = new QWidget(groupBox_2);
        widget->setObjectName(QString::fromUtf8("widget"));
        gridLayout_2 = new QGridLayout(widget);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        gridLayout_2->setSizeConstraint(QLayout::SetDefaultConstraint);
        toolButton_3 = new QToolButton(widget);
        toolButton_3->setObjectName(QString::fromUtf8("toolButton_3"));
        toolButton_3->setCheckable(true);

        gridLayout_2->addWidget(toolButton_3, 0, 0, 1, 1);

        toolButton_4 = new QToolButton(widget);
        toolButton_4->setObjectName(QString::fromUtf8("toolButton_4"));
        toolButton_4->setPopupMode(QToolButton::InstantPopup);

        gridLayout_2->addWidget(toolButton_4, 0, 1, 1, 1);

        toolButton_5 = new QToolButton(widget);
        toolButton_5->setObjectName(QString::fromUtf8("toolButton_5"));
        toolButton_5->setPopupMode(QToolButton::MenuButtonPopup);

        gridLayout_2->addWidget(toolButton_5, 0, 2, 1, 1);

        frame_2 = new QFrame(widget);
        frame_2->setObjectName(QString::fromUtf8("frame_2"));
        frame_2->setFrameShape(QFrame::VLine);
        frame_2->setFrameShadow(QFrame::Raised);

        gridLayout_2->addWidget(frame_2, 0, 3, 2, 1);

        toolBarContainer = new QWidget(widget);
        toolBarContainer->setObjectName(QString::fromUtf8("toolBarContainer"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(toolBarContainer->sizePolicy().hasHeightForWidth());
        toolBarContainer->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(toolBarContainer, 0, 4, 1, 4);

        toolButton_6 = new QToolButton(widget);
        toolButton_6->setObjectName(QString::fromUtf8("toolButton_6"));
        toolButton_6->setCheckable(true);
        toolButton_6->setAutoRaise(true);

        gridLayout_2->addWidget(toolButton_6, 1, 0, 1, 1);

        toolButton_7 = new QToolButton(widget);
        toolButton_7->setObjectName(QString::fromUtf8("toolButton_7"));
        toolButton_7->setPopupMode(QToolButton::InstantPopup);
        toolButton_7->setAutoRaise(true);

        gridLayout_2->addWidget(toolButton_7, 1, 1, 1, 1);

        toolButton_8 = new QToolButton(widget);
        toolButton_8->setObjectName(QString::fromUtf8("toolButton_8"));
        toolButton_8->setPopupMode(QToolButton::MenuButtonPopup);
        toolButton_8->setAutoRaise(true);

        gridLayout_2->addWidget(toolButton_8, 1, 2, 1, 1);

        toolButton_9 = new QToolButton(widget);
        toolButton_9->setObjectName(QString::fromUtf8("toolButton_9"));
        toolButton_9->setArrowType(Qt::UpArrow);

        gridLayout_2->addWidget(toolButton_9, 1, 4, 1, 1);

        toolButton_10 = new QToolButton(widget);
        toolButton_10->setObjectName(QString::fromUtf8("toolButton_10"));
        toolButton_10->setCheckable(false);
        toolButton_10->setArrowType(Qt::DownArrow);

        gridLayout_2->addWidget(toolButton_10, 1, 5, 1, 1);

        toolButton_11 = new QToolButton(widget);
        toolButton_11->setObjectName(QString::fromUtf8("toolButton_11"));
        toolButton_11->setArrowType(Qt::LeftArrow);

        gridLayout_2->addWidget(toolButton_11, 1, 6, 1, 1);

        toolButton_12 = new QToolButton(widget);
        toolButton_12->setObjectName(QString::fromUtf8("toolButton_12"));
        toolButton_12->setArrowType(Qt::RightArrow);

        gridLayout_2->addWidget(toolButton_12, 1, 7, 1, 1);


        gridLayout_3->addWidget(widget, 0, 0, 1, 4);

        label_11 = new QLabel(groupBox_2);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_11, 1, 0, 1, 1);

        textPosition = new KComboBox(groupBox_2);
        textPosition->addItem(QString());
        textPosition->addItem(QString());
        textPosition->addItem(QString());
        textPosition->addItem(QString());
        textPosition->setObjectName(QString::fromUtf8("textPosition"));

        gridLayout_3->addWidget(textPosition, 1, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(120, 17, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_5, 1, 2, 1, 2);

        label_12 = new QLabel(groupBox_2);
        label_12->setObjectName(QString::fromUtf8("label_12"));
        label_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_12, 2, 0, 1, 1);

        iconSize = new KComboBox(groupBox_2);
        iconSize->addItem(QString());
        iconSize->addItem(QString());
        iconSize->addItem(QString());
        iconSize->addItem(QString());
        iconSize->setObjectName(QString::fromUtf8("iconSize"));

        gridLayout_3->addWidget(iconSize, 2, 1, 1, 1);

        gridLayout_3->setColumnStretch(1, 1);
        gridLayout_3->setColumnStretch(2, 1);
        gridLayout_3->setColumnStretch(3, 1);

        gridLayout->addWidget(groupBox_2, 1, 0, 1, 2);

#if QT_CONFIG(shortcut)
        label_11->setBuddy(textPosition);
        label_12->setBuddy(iconSize);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(pushButton, pushButton_2);
        QWidget::setTabOrder(pushButton_2, kcombobox);
        QWidget::setTabOrder(kcombobox, toolButton);
        QWidget::setTabOrder(toolButton, pushButton_3);
        QWidget::setTabOrder(pushButton_3, pushButton_4);
        QWidget::setTabOrder(pushButton_4, kcombobox_2);
        QWidget::setTabOrder(kcombobox_2, toolButton_2);
        QWidget::setTabOrder(toolButton_2, flatButtonCheckBox);
        QWidget::setTabOrder(flatButtonCheckBox, toolButton_3);
        QWidget::setTabOrder(toolButton_3, toolButton_4);
        QWidget::setTabOrder(toolButton_4, toolButton_5);
        QWidget::setTabOrder(toolButton_5, toolButton_6);
        QWidget::setTabOrder(toolButton_6, toolButton_7);
        QWidget::setTabOrder(toolButton_7, toolButton_8);
        QWidget::setTabOrder(toolButton_8, toolButton_9);
        QWidget::setTabOrder(toolButton_9, toolButton_10);
        QWidget::setTabOrder(toolButton_10, toolButton_11);
        QWidget::setTabOrder(toolButton_11, toolButton_12);
        QWidget::setTabOrder(toolButton_12, textPosition);
        QWidget::setTabOrder(textPosition, iconSize);
        QWidget::setTabOrder(iconSize, checkBox);
        QWidget::setTabOrder(checkBox, checkBox_2);
        QWidget::setTabOrder(checkBox_2, checkBox_3);
        QWidget::setTabOrder(checkBox_3, radioButton);
        QWidget::setTabOrder(radioButton, radioButton_2);
        QWidget::setTabOrder(radioButton_2, radioButton_3);

        retranslateUi(ButtonDemoWidget);

        kcombobox->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(ButtonDemoWidget);
    } // setupUi

    void retranslateUi(QWidget *ButtonDemoWidget)
    {
        groupBox_3->setTitle(tr2i18n("Checkboxes", nullptr));
        checkBox->setText(tr2i18n("Off", nullptr));
        checkBox_2->setText(tr2i18n("Partial", nullptr));
        checkBox_3->setText(tr2i18n("On", nullptr));
        groupBox_4->setTitle(tr2i18n("Radiobuttons", nullptr));
        radioButton->setText(tr2i18n("F&irst Choice", nullptr));
        radioButton_2->setText(tr2i18n("Seco&nd Choice", nullptr));
        radioButton_3->setText(tr2i18n("&Third Choice", nullptr));
        groupBox->setTitle(tr2i18n("Pushbuttons", nullptr));
        label_7->setText(tr2i18n("Text only:", nullptr));
        kcombobox->setItemText(0, tr2i18n("Small", nullptr));
        kcombobox->setItemText(1, tr2i18n("Normal", nullptr));
        kcombobox->setItemText(2, tr2i18n("Large", nullptr));

#if QT_CONFIG(tooltip)
        kcombobox->setToolTip(tr2i18n("This is a normal, text only combo box", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Text and icon:", nullptr));
        flatButtonCheckBox->setText(tr2i18n("Use flat buttons", nullptr));
#if QT_CONFIG(tooltip)
        kcombobox_2->setToolTip(tr2i18n("This is a normal, text and icon combo box", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        toolButton->setToolTip(tr2i18n("This is a normal, text only tool button", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButton->setText(tr2i18n("Normal", nullptr));
#if QT_CONFIG(tooltip)
        toolButton_2->setToolTip(tr2i18n("This is a normal, text and icon tool button", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButton_2->setText(tr2i18n("Normal", nullptr));
#if QT_CONFIG(tooltip)
        pushButton->setToolTip(tr2i18n("This is a normal, text only button", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton->setText(tr2i18n("Normal", nullptr));
#if QT_CONFIG(tooltip)
        pushButton_2->setToolTip(tr2i18n("This is a normal, text only button with menu", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_2->setText(tr2i18n("Normal", nullptr));
#if QT_CONFIG(tooltip)
        pushButton_3->setToolTip(tr2i18n("This is a normal, text and icon button", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_3->setText(tr2i18n("Normal", nullptr));
#if QT_CONFIG(tooltip)
        pushButton_4->setToolTip(tr2i18n("This is a normal, text and icon button with menu", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_4->setText(tr2i18n("Normal", nullptr));
        groupBox_2->setTitle(tr2i18n("Toolbuttons", nullptr));
        toolButton_3->setText(tr2i18n("Normal", nullptr));
        toolButton_4->setText(tr2i18n("Normal", nullptr));
        toolButton_5->setText(tr2i18n("Normal", nullptr));
        toolButton_6->setText(tr2i18n("Flat", nullptr));
        toolButton_7->setText(tr2i18n("Flat", nullptr));
        toolButton_8->setText(tr2i18n("Flat", nullptr));
        toolButton_9->setText(tr2i18n("Up Arrow", nullptr));
        toolButton_10->setText(tr2i18n("Down Arrow", nullptr));
        toolButton_11->setText(tr2i18n("Left Arrow", nullptr));
        toolButton_12->setText(tr2i18n("Right Arrow", nullptr));
        label_11->setText(tr2i18n("Te&xt position:", nullptr));
        textPosition->setItemText(0, tr2i18n("Icons Only", nullptr));
        textPosition->setItemText(1, tr2i18n("Text Only", nullptr));
        textPosition->setItemText(2, tr2i18n("Text Alongside Icons", nullptr));
        textPosition->setItemText(3, tr2i18n("Text Under Icons", nullptr));

        label_12->setText(tr2i18n("Icon si&ze:", nullptr));
        iconSize->setItemText(0, tr2i18n("Small (16x16)", nullptr));
        iconSize->setItemText(1, tr2i18n("Medium (22x22)", nullptr));
        iconSize->setItemText(2, tr2i18n("Large (32x32)", nullptr));
        iconSize->setItemText(3, tr2i18n("Huge (48x48)", nullptr));

        (void)ButtonDemoWidget;
    } // retranslateUi

};

namespace Ui {
    class ButtonDemoWidget: public Ui_ButtonDemoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENBUTTONDEMOWIDGET_H

