/********************************************************************************
** Form generated from reading UI file 'oxygenframedemowidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENFRAMEDEMOWIDGET_H
#define UI_OXYGENFRAMEDEMOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_FrameDemoWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KComboBox *directionComboBox;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *frameLayout;
    QFrame *frame;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_2;
    QRadioButton *raisedFrameRadioButton;
    QRadioButton *plainFrameRadioButton;
    QRadioButton *sunkenFrameRadioButton;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *flatGroupBoxCheckBox;
    QSpacerItem *verticalSpacer_2;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *msgLayout;
    QFrame *msgFrame;
    QVBoxLayout *verticalLayout_5;

    void setupUi(QWidget *FrameDemoWidget)
    {
        if (FrameDemoWidget->objectName().isEmpty())
            FrameDemoWidget->setObjectName("FrameDemoWidget");
        FrameDemoWidget->resize(487, 418);
        verticalLayout = new QVBoxLayout(FrameDemoWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(FrameDemoWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(label);

        directionComboBox = new KComboBox(FrameDemoWidget);
        directionComboBox->addItem(QString());
        directionComboBox->addItem(QString());
        directionComboBox->addItem(QString());
        directionComboBox->addItem(QString());
        directionComboBox->setObjectName("directionComboBox");

        horizontalLayout->addWidget(directionComboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        frameLayout = new QHBoxLayout();
        frameLayout->setObjectName("frameLayout");
        frame = new QFrame(FrameDemoWidget);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        verticalLayout_2 = new QVBoxLayout(frame);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_2 = new QLabel(frame);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignCenter);

        verticalLayout_2->addWidget(label_2);

        raisedFrameRadioButton = new QRadioButton(frame);
        raisedFrameRadioButton->setObjectName("raisedFrameRadioButton");
        raisedFrameRadioButton->setChecked(true);

        verticalLayout_2->addWidget(raisedFrameRadioButton);

        plainFrameRadioButton = new QRadioButton(frame);
        plainFrameRadioButton->setObjectName("plainFrameRadioButton");
        plainFrameRadioButton->setEnabled(true);

        verticalLayout_2->addWidget(plainFrameRadioButton);

        sunkenFrameRadioButton = new QRadioButton(frame);
        sunkenFrameRadioButton->setObjectName("sunkenFrameRadioButton");

        verticalLayout_2->addWidget(sunkenFrameRadioButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        frameLayout->addWidget(frame);

        groupBox = new QGroupBox(FrameDemoWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        flatGroupBoxCheckBox = new QCheckBox(groupBox);
        flatGroupBoxCheckBox->setObjectName("flatGroupBoxCheckBox");

        verticalLayout_3->addWidget(flatGroupBoxCheckBox);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);


        frameLayout->addWidget(groupBox);

        tabWidget = new QTabWidget(FrameDemoWidget);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_4 = new QVBoxLayout(tab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        tabWidget->addTab(tab, QString());

        frameLayout->addWidget(tabWidget);

        frameLayout->setStretch(0, 1);
        frameLayout->setStretch(1, 1);
        frameLayout->setStretch(2, 1);

        verticalLayout->addLayout(frameLayout);

        msgLayout = new QHBoxLayout();
        msgLayout->setObjectName("msgLayout");
        msgFrame = new QFrame(FrameDemoWidget);
        msgFrame->setObjectName("msgFrame");
        msgFrame->setFrameShape(QFrame::Panel);
        verticalLayout_5 = new QVBoxLayout(msgFrame);
        verticalLayout_5->setObjectName("verticalLayout_5");

        msgLayout->addWidget(msgFrame);

        msgLayout->setStretch(0, 1);

        verticalLayout->addLayout(msgLayout);

#if QT_CONFIG(shortcut)
        label->setBuddy(directionComboBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(directionComboBox, flatGroupBoxCheckBox);
        QWidget::setTabOrder(flatGroupBoxCheckBox, raisedFrameRadioButton);
        QWidget::setTabOrder(raisedFrameRadioButton, plainFrameRadioButton);
        QWidget::setTabOrder(plainFrameRadioButton, sunkenFrameRadioButton);

        retranslateUi(FrameDemoWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(FrameDemoWidget);
    } // setupUi

    void retranslateUi(QWidget *FrameDemoWidget)
    {
        label->setText(tr2i18n("&Layout direction:", nullptr));
        directionComboBox->setItemText(0, tr2i18n("Left to Right", nullptr));
        directionComboBox->setItemText(1, tr2i18n("Right to Left", nullptr));
        directionComboBox->setItemText(2, tr2i18n("Top to Bottom", nullptr));
        directionComboBox->setItemText(3, tr2i18n("Bottom to Top", nullptr));

        label_2->setText(tr2i18n("Frame", nullptr));
        raisedFrameRadioButton->setText(tr2i18n("&Raised", nullptr));
        plainFrameRadioButton->setText(tr2i18n("&Flat", "Flat frame. No frame is actually drawn."));
        sunkenFrameRadioButton->setText(tr2i18n("S&unken", nullptr));
        groupBox->setTitle(tr2i18n("GroupBox", nullptr));
        flatGroupBoxCheckBox->setText(tr2i18n("Flat", "Flat group box. No frame is actually drawn"));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Tab Widget", nullptr));
        (void)FrameDemoWidget;
    } // retranslateUi

};

namespace Ui {
    class FrameDemoWidget: public Ui_FrameDemoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENFRAMEDEMOWIDGET_H

