/********************************************************************************
** Form generated from reading UI file 'oxygenanimationconfigitem.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENANIMATIONCONFIGITEM_H
#define UI_OXYGENANIMATIONCONFIGITEM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AnimationConfigItem
{
public:
    QHBoxLayout *horizontalLayout;
    QCheckBox *enableCheckBox;
    QToolButton *configurationButton;
    QToolButton *descriptionButton;

    void setupUi(QWidget *AnimationConfigItem)
    {
        if (AnimationConfigItem->objectName().isEmpty())
            AnimationConfigItem->setObjectName("AnimationConfigItem");
        AnimationConfigItem->resize(400, 31);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AnimationConfigItem->sizePolicy().hasHeightForWidth());
        AnimationConfigItem->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(AnimationConfigItem);
        horizontalLayout->setObjectName("horizontalLayout");
        enableCheckBox = new QCheckBox(AnimationConfigItem);
        enableCheckBox->setObjectName("enableCheckBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(enableCheckBox->sizePolicy().hasHeightForWidth());
        enableCheckBox->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(enableCheckBox);

        configurationButton = new QToolButton(AnimationConfigItem);
        configurationButton->setObjectName("configurationButton");
        configurationButton->setCheckable(true);
        configurationButton->setAutoRaise(false);

        horizontalLayout->addWidget(configurationButton);

        descriptionButton = new QToolButton(AnimationConfigItem);
        descriptionButton->setObjectName("descriptionButton");
        descriptionButton->setAutoRaise(false);

        horizontalLayout->addWidget(descriptionButton);


        retranslateUi(AnimationConfigItem);

        QMetaObject::connectSlotsByName(AnimationConfigItem);
    } // setupUi

    void retranslateUi(QWidget *AnimationConfigItem)
    {
        enableCheckBox->setText(tr2i18n("CheckBox", nullptr));
        configurationButton->setText(tr2i18n("...", nullptr));
        descriptionButton->setText(tr2i18n("...", nullptr));
        (void)AnimationConfigItem;
    } // retranslateUi

};

namespace Ui {
    class AnimationConfigItem: public Ui_AnimationConfigItem {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENANIMATIONCONFIGITEM_H

