/********************************************************************************
** Form generated from reading UI file 'oxygenanimationconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENANIMATIONCONFIGWIDGET_H
#define UI_OXYGENANIMATIONCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AnimationConfigWidget
{
public:
    QGridLayout *gridLayout;
    QCheckBox *animationsEnabled;

    void setupUi(QWidget *AnimationConfigWidget)
    {
        if (AnimationConfigWidget->objectName().isEmpty())
            AnimationConfigWidget->setObjectName("AnimationConfigWidget");
        AnimationConfigWidget->resize(400, 300);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AnimationConfigWidget->sizePolicy().hasHeightForWidth());
        AnimationConfigWidget->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(AnimationConfigWidget);
        gridLayout->setObjectName("gridLayout");
        animationsEnabled = new QCheckBox(AnimationConfigWidget);
        animationsEnabled->setObjectName("animationsEnabled");

        gridLayout->addWidget(animationsEnabled, 0, 0, 1, 2);


        retranslateUi(AnimationConfigWidget);

        QMetaObject::connectSlotsByName(AnimationConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *AnimationConfigWidget)
    {
        animationsEnabled->setText(tr2i18n("Enable animations", nullptr));
        (void)AnimationConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class AnimationConfigWidget: public Ui_AnimationConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENANIMATIONCONFIGWIDGET_H

