/********************************************************************************
** Form generated from reading UI file 'oxygenfollowmouseanimationconfigbox.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENFOLLOWMOUSEANIMATIONCONFIGBOX_H
#define UI_OXYGENFOLLOWMOUSEANIMATIONCONFIGBOX_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_FollowMouseAnimationConfigBox
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    KComboBox *typeComboBox;
    QLabel *durationLabel;
    QLabel *followMouseDurationLabel;
    QSpacerItem *horizontalSpacer;
    QSpinBox *durationSpinBox;
    QSpinBox *followMouseDurationSpinBox;

    void setupUi(QFrame *FollowMouseAnimationConfigBox)
    {
        if (FollowMouseAnimationConfigBox->objectName().isEmpty())
            FollowMouseAnimationConfigBox->setObjectName("FollowMouseAnimationConfigBox");
        FollowMouseAnimationConfigBox->resize(400, 94);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(FollowMouseAnimationConfigBox->sizePolicy().hasHeightForWidth());
        FollowMouseAnimationConfigBox->setSizePolicy(sizePolicy);
        FollowMouseAnimationConfigBox->setFrameShape(QFrame::StyledPanel);
        FollowMouseAnimationConfigBox->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(FollowMouseAnimationConfigBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(FollowMouseAnimationConfigBox);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        typeComboBox = new KComboBox(FollowMouseAnimationConfigBox);
        typeComboBox->addItem(QString());
        typeComboBox->addItem(QString());
        typeComboBox->setObjectName("typeComboBox");

        gridLayout->addWidget(typeComboBox, 0, 1, 1, 1);

        durationLabel = new QLabel(FollowMouseAnimationConfigBox);
        durationLabel->setObjectName("durationLabel");
        durationLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(durationLabel, 1, 0, 1, 1);

        followMouseDurationLabel = new QLabel(FollowMouseAnimationConfigBox);
        followMouseDurationLabel->setObjectName("followMouseDurationLabel");
        followMouseDurationLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(followMouseDurationLabel, 2, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        durationSpinBox = new QSpinBox(FollowMouseAnimationConfigBox);
        durationSpinBox->setObjectName("durationSpinBox");
        durationSpinBox->setMinimum(5);
        durationSpinBox->setMaximum(2000);
        durationSpinBox->setSingleStep(5);

        gridLayout->addWidget(durationSpinBox, 1, 1, 1, 1);

        followMouseDurationSpinBox = new QSpinBox(FollowMouseAnimationConfigBox);
        followMouseDurationSpinBox->setObjectName("followMouseDurationSpinBox");
        followMouseDurationSpinBox->setMinimum(5);
        followMouseDurationSpinBox->setMaximum(2000);
        followMouseDurationSpinBox->setSingleStep(5);

        gridLayout->addWidget(followMouseDurationSpinBox, 2, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(typeComboBox);
        durationLabel->setBuddy(durationSpinBox);
        followMouseDurationLabel->setBuddy(followMouseDurationSpinBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(FollowMouseAnimationConfigBox);

        QMetaObject::connectSlotsByName(FollowMouseAnimationConfigBox);
    } // setupUi

    void retranslateUi(QFrame *FollowMouseAnimationConfigBox)
    {
        FollowMouseAnimationConfigBox->setWindowTitle(tr2i18n("Frame", nullptr));
        label->setText(tr2i18n("Animation type:", nullptr));
        typeComboBox->setItemText(0, tr2i18n("Fade", nullptr));
        typeComboBox->setItemText(1, tr2i18n("Follow Mouse", nullptr));

        durationLabel->setText(tr2i18n("Fade duration:", nullptr));
        followMouseDurationLabel->setText(tr2i18n("Follow mouse duration:", nullptr));
        durationSpinBox->setSuffix(tr2i18n(" ms", nullptr));
        followMouseDurationSpinBox->setSuffix(tr2i18n(" ms", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FollowMouseAnimationConfigBox: public Ui_FollowMouseAnimationConfigBox {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENFOLLOWMOUSEANIMATIONCONFIGBOX_H

