/*
    hard-coded property names to disable some of oxygen features

    SPDX-FileCopyrightText: 2012 Hugo Pereira Da Costa <hugo.pereira@free.fr>
    SPDX-FileCopyrightText: 2003 - 2010 Craig Drummond <craig.p.drummond@gmail.com>
    SPDX-License-Identifier: LGPL-2.0-or-later

    Largely inspired from Qtcurve style
*/

#include "oxygenpropertynames.h"

namespace Oxygen
{
const char PropertyNames::noAnimations[] = "_kde_no_animations";
const char PropertyNames::noWindowGrab[] = "_kde_no_window_grab";
const char PropertyNames::toolButtonAlignment[] = "_kde_toolbutton_alignment";
const char PropertyNames::netWMForceShadow[] = "_KDE_NET_WM_FORCE_SHADOW";
const char PropertyNames::netWMSkipShadow[] = "_KDE_NET_WM_SKIP_SHADOW";
}
