/********************************************************************************
** Form generated from reading UI file 'oxygendetectwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENDETECTWIDGET_H
#define UI_OXYGENDETECTWIDGET_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OxygenDetectWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *windowClass;
    QLabel *label_2;
    QLabel *windowTitle;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *windowClassCheckBox;
    QRadioButton *windowTitleCheckBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OxygenDetectWidget)
    {
        if (OxygenDetectWidget->objectName().isEmpty())
            OxygenDetectWidget->setObjectName("OxygenDetectWidget");
        OxygenDetectWidget->resize(400, 239);
        verticalLayout = new QVBoxLayout(OxygenDetectWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(OxygenDetectWidget);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        windowClass = new QLabel(groupBox);
        windowClass->setObjectName("windowClass");
        windowClass->setText(QString::fromUtf8("TextLabel"));

        gridLayout->addWidget(windowClass, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        windowTitle = new QLabel(groupBox);
        windowTitle->setObjectName("windowTitle");
        windowTitle->setText(QString::fromUtf8("TextLabel"));

        gridLayout->addWidget(windowTitle, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(OxygenDetectWidget);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        windowClassCheckBox = new QRadioButton(groupBox_2);
        windowClassCheckBox->setObjectName("windowClassCheckBox");

        verticalLayout_2->addWidget(windowClassCheckBox);

        windowTitleCheckBox = new QRadioButton(groupBox_2);
        windowTitleCheckBox->setObjectName("windowTitleCheckBox");
        windowTitleCheckBox->setLocale(QLocale(QLocale::French, QLocale::France));

        verticalLayout_2->addWidget(windowTitleCheckBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        verticalLayout->addWidget(groupBox_2);

        buttonBox = new QDialogButtonBox(OxygenDetectWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(OxygenDetectWidget);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, OxygenDetectWidget, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, OxygenDetectWidget, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(OxygenDetectWidget);
    } // setupUi

    void retranslateUi(QDialog *OxygenDetectWidget)
    {
        OxygenDetectWidget->setWindowTitle(tr2i18n("Dialog", nullptr));
        groupBox->setTitle(tr2i18n("Information about Selected Window", nullptr));
        label->setText(tr2i18n("Class: ", nullptr));
        label_2->setText(tr2i18n("Title: ", nullptr));
        groupBox_2->setTitle(tr2i18n("Window Property Selection", nullptr));
        windowClassCheckBox->setText(tr2i18n("Use window class (whole application)", nullptr));
        windowTitleCheckBox->setText(tr2i18n("Use window title", nullptr));
    } // retranslateUi

};

namespace Ui {
    class OxygenDetectWidget: public Ui_OxygenDetectWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENDETECTWIDGET_H

