/********************************************************************************
** Form generated from reading UI file 'oxygenconfigurationui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENCONFIGURATIONUI_H
#define UI_OXYGENCONFIGURATIONUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "config/oxygenanimationconfigwidget.h"
#include "config/oxygenexceptionlistwidget.h"
#include "oxygenshadowconfigwidget.h"

QT_BEGIN_NAMESPACE

class Ui_OxygenConfigurationUI
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout;
    QComboBox *buttonSize;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QComboBox *titleAlignment;
    QLabel *label_4;
    QCheckBox *drawBorderOnMaximizedWindows;
    QSpacerItem *verticalSpacer;
    QCheckBox *useWindowColors;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_4;
    Oxygen::AnimationConfigWidget *animationConfigWidget;
    QWidget *tab_4;
    QGridLayout *gridLayout_2;
    Oxygen::ShadowConfigWidget *activeShadowConfiguration;
    Oxygen::ShadowConfigWidget *inactiveShadowConfiguration;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout_3;
    Oxygen::ExceptionListWidget *exceptions;

    void setupUi(QWidget *OxygenConfigurationUI)
    {
        if (OxygenConfigurationUI->objectName().isEmpty())
            OxygenConfigurationUI->setObjectName("OxygenConfigurationUI");
        OxygenConfigurationUI->resize(488, 386);
        verticalLayout = new QVBoxLayout(OxygenConfigurationUI);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(OxygenConfigurationUI);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout = new QGridLayout(tab);
        gridLayout->setObjectName("gridLayout");
        buttonSize = new QComboBox(tab);
        buttonSize->addItem(QString());
        buttonSize->addItem(QString());
        buttonSize->addItem(QString());
        buttonSize->addItem(QString());
        buttonSize->setObjectName("buttonSize");

        gridLayout->addWidget(buttonSize, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(205, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        label_3 = new QLabel(tab);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        titleAlignment = new QComboBox(tab);
        titleAlignment->addItem(QString());
        titleAlignment->addItem(QString());
        titleAlignment->addItem(QString());
        titleAlignment->addItem(QString());
        titleAlignment->setObjectName("titleAlignment");

        gridLayout->addWidget(titleAlignment, 0, 1, 1, 1);

        label_4 = new QLabel(tab);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        drawBorderOnMaximizedWindows = new QCheckBox(tab);
        drawBorderOnMaximizedWindows->setObjectName("drawBorderOnMaximizedWindows");

        gridLayout->addWidget(drawBorderOnMaximizedWindows, 2, 0, 1, 3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 5, 0, 1, 3);

        useWindowColors = new QCheckBox(tab);
        useWindowColors->setObjectName("useWindowColors");

        gridLayout->addWidget(useWindowColors, 4, 0, 1, 3);

        tabWidget->addTab(tab, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout_4 = new QVBoxLayout(tab_3);
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        animationConfigWidget = new Oxygen::AnimationConfigWidget(tab_3);
        animationConfigWidget->setObjectName("animationConfigWidget");

        verticalLayout_4->addWidget(animationConfigWidget);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout_2 = new QGridLayout(tab_4);
        gridLayout_2->setObjectName("gridLayout_2");
        activeShadowConfiguration = new Oxygen::ShadowConfigWidget(tab_4);
        activeShadowConfiguration->setObjectName("activeShadowConfiguration");
        activeShadowConfiguration->setCheckable(true);

        gridLayout_2->addWidget(activeShadowConfiguration, 0, 0, 1, 1);

        inactiveShadowConfiguration = new Oxygen::ShadowConfigWidget(tab_4);
        inactiveShadowConfiguration->setObjectName("inactiveShadowConfiguration");
        inactiveShadowConfiguration->setCheckable(true);

        gridLayout_2->addWidget(inactiveShadowConfiguration, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 1, 0, 1, 2);

        tabWidget->addTab(tab_4, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout_3 = new QVBoxLayout(tab_2);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        exceptions = new Oxygen::ExceptionListWidget(tab_2);
        exceptions->setObjectName("exceptions");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(exceptions->sizePolicy().hasHeightForWidth());
        exceptions->setSizePolicy(sizePolicy);

        verticalLayout_3->addWidget(exceptions);

        tabWidget->addTab(tab_2, QString());

        verticalLayout->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(titleAlignment);
        label_4->setBuddy(buttonSize);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OxygenConfigurationUI);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(OxygenConfigurationUI);
    } // setupUi

    void retranslateUi(QWidget *OxygenConfigurationUI)
    {
        buttonSize->setItemText(0, tr2i18n("Small", "@item:inlistbox Button size:"));
        buttonSize->setItemText(1, tr2i18n("Normal", "@item:inlistbox Button size:"));
        buttonSize->setItemText(2, tr2i18n("Large", "@item:inlistbox Button size:"));
        buttonSize->setItemText(3, tr2i18n("Very Large", "@item:inlistbox Button size:"));

        label_3->setText(tr2i18n("Tit&le alignment:", nullptr));
        titleAlignment->setItemText(0, tr2i18n("Left", nullptr));
        titleAlignment->setItemText(1, tr2i18n("Center", nullptr));
        titleAlignment->setItemText(2, tr2i18n("Center (Full Width)", nullptr));
        titleAlignment->setItemText(3, tr2i18n("Right", nullptr));

        label_4->setText(tr2i18n("B&utton size:", nullptr));
        drawBorderOnMaximizedWindows->setText(tr2i18n("Allow resizing maximized windows from window edges", nullptr));
        useWindowColors->setText(tr2i18n("Use the same colors for title bar and window content", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("General", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Animations", nullptr));
        activeShadowConfiguration->setTitle(tr2i18n("Active Window Glow", nullptr));
        inactiveShadowConfiguration->setTitle(tr2i18n("Window Drop-Down Shadow", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Shadows", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Window-Specific Overrides", nullptr));
        (void)OxygenConfigurationUI;
    } // retranslateUi

};

namespace Ui {
    class OxygenConfigurationUI: public Ui_OxygenConfigurationUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENCONFIGURATIONUI_H

