// This file is generated by kconfig_compiler_kf5 from oxygeninactiveshadowconfigdata.kcfg.
// All changes you do to this file will be lost.
#ifndef OXYGEN_INACTIVESHADOWCONFIGURATION_H
#define OXYGEN_INACTIVESHADOWCONFIGURATION_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace Oxygen {

class InactiveShadowConfiguration : public KConfigSkeleton
{
  public:

    static InactiveShadowConfiguration *self();
    ~InactiveShadowConfiguration() override;

    /**
      Set Enabled
    */
    static
    void setEnabled( bool v )
    {
      if (!self()->isEnabledImmutable())
        self()->mEnabled = v;
    }

    /**
      Get Enabled
    */
    static
    bool enabled()
    {
      return self()->mEnabled;
    }

    /**
      Is Enabled Immutable
    */
    static
    bool isEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Enabled" ) );
    }

    /**
      Set ShadowSize
    */
    static
    void setShadowSize( int v )
    {
      if (!self()->isShadowSizeImmutable())
        self()->mShadowSize = v;
    }

    /**
      Get ShadowSize
    */
    static
    int shadowSize()
    {
      return self()->mShadowSize;
    }

    /**
      Is ShadowSize Immutable
    */
    static
    bool isShadowSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ShadowSize" ) );
    }

    /**
      Set VerticalOffset
    */
    static
    void setVerticalOffset( double v )
    {
      if (!self()->isVerticalOffsetImmutable())
        self()->mVerticalOffset = v;
    }

    /**
      Get VerticalOffset
    */
    static
    double verticalOffset()
    {
      return self()->mVerticalOffset;
    }

    /**
      Is VerticalOffset Immutable
    */
    static
    bool isVerticalOffsetImmutable()
    {
      return self()->isImmutable( QStringLiteral( "VerticalOffset" ) );
    }

    /**
      Set InnerColor
    */
    static
    void setInnerColor( const QColor & v )
    {
      if (!self()->isInnerColorImmutable())
        self()->mInnerColor = v;
    }

    /**
      Get InnerColor
    */
    static
    QColor innerColor()
    {
      return self()->mInnerColor;
    }

    /**
      Is InnerColor Immutable
    */
    static
    bool isInnerColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "InnerColor" ) );
    }

    /**
      Set OuterColor
    */
    static
    void setOuterColor( const QColor & v )
    {
      if (!self()->isOuterColorImmutable())
        self()->mOuterColor = v;
    }

    /**
      Get OuterColor
    */
    static
    QColor outerColor()
    {
      return self()->mOuterColor;
    }

    /**
      Is OuterColor Immutable
    */
    static
    bool isOuterColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "OuterColor" ) );
    }

    /**
      Set UseOuterColor
    */
    static
    void setUseOuterColor( bool v )
    {
      if (!self()->isUseOuterColorImmutable())
        self()->mUseOuterColor = v;
    }

    /**
      Get UseOuterColor
    */
    static
    bool useOuterColor()
    {
      return self()->mUseOuterColor;
    }

    /**
      Is UseOuterColor Immutable
    */
    static
    bool isUseOuterColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseOuterColor" ) );
    }

  protected:
    InactiveShadowConfiguration();
    friend class InactiveShadowConfigurationHelper;


    // InactiveShadow
    bool mEnabled;
    int mShadowSize;
    double mVerticalOffset;
    QColor mInnerColor;
    QColor mOuterColor;
    bool mUseOuterColor;

  private:
};

}

#endif

