#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'oxygeninputdemowidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENINPUTDEMOWIDGET_H
#define UI_OXYGENINPUTDEMOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_InputDemoWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    KLineEdit *klineedit;
    QSpacerItem *horizontalSpacer;
    QLabel *label_2;
    KLineEdit *klineedit_2;
    QLabel *label_3;
    KComboBox *kcombobox;
    QLabel *label_4;
    QFrame *frame;
    QLabel *label_5;
    QCheckBox *wrapCheckBox;
    QCheckBox *flatCheckBox;
    QTextEdit *textedit;
    QSpinBox *kintspinbox;

    void setupUi(QWidget *InputDemoWidget)
    {
        if (InputDemoWidget->objectName().isEmpty())
            InputDemoWidget->setObjectName(QString::fromUtf8("InputDemoWidget"));
        InputDemoWidget->resize(621, 521);
        gridLayout = new QGridLayout(InputDemoWidget);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(InputDemoWidget);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        klineedit = new KLineEdit(InputDemoWidget);
        klineedit->setObjectName(QString::fromUtf8("klineedit"));
        klineedit->setProperty("showClearButton", QVariant(true));

        gridLayout->addWidget(klineedit, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(126, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        label_2 = new QLabel(InputDemoWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        klineedit_2 = new KLineEdit(InputDemoWidget);
        klineedit_2->setObjectName(QString::fromUtf8("klineedit_2"));
        klineedit_2->setEchoMode(QLineEdit::Password);
        klineedit_2->setProperty("showClearButton", QVariant(true));

        gridLayout->addWidget(klineedit_2, 1, 1, 1, 1);

        label_3 = new QLabel(InputDemoWidget);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        kcombobox = new KComboBox(InputDemoWidget);
        kcombobox->addItem(QString());
        kcombobox->addItem(QString());
        kcombobox->addItem(QString());
        kcombobox->setObjectName(QString::fromUtf8("kcombobox"));
        kcombobox->setEditable(true);

        gridLayout->addWidget(kcombobox, 2, 1, 1, 1);

        label_4 = new QLabel(InputDemoWidget);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        frame = new QFrame(InputDemoWidget);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setFrameShape(QFrame::HLine);
        frame->setFrameShadow(QFrame::Raised);

        gridLayout->addWidget(frame, 5, 0, 1, 3);

        label_5 = new QLabel(InputDemoWidget);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 6, 0, 1, 1);

        wrapCheckBox = new QCheckBox(InputDemoWidget);
        wrapCheckBox->setObjectName(QString::fromUtf8("wrapCheckBox"));

        gridLayout->addWidget(wrapCheckBox, 8, 0, 1, 1);

        flatCheckBox = new QCheckBox(InputDemoWidget);
        flatCheckBox->setObjectName(QString::fromUtf8("flatCheckBox"));

        gridLayout->addWidget(flatCheckBox, 4, 0, 1, 2);

        textedit = new QTextEdit(InputDemoWidget);
        textedit->setObjectName(QString::fromUtf8("textedit"));

        gridLayout->addWidget(textedit, 7, 0, 1, 3);

        kintspinbox = new QSpinBox(InputDemoWidget);
        kintspinbox->setObjectName(QString::fromUtf8("kintspinbox"));

        gridLayout->addWidget(kintspinbox, 3, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(klineedit);
        label_2->setBuddy(klineedit_2);
        label_3->setBuddy(kcombobox);
        label_4->setBuddy(kintspinbox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(klineedit, klineedit_2);
        QWidget::setTabOrder(klineedit_2, kcombobox);
        QWidget::setTabOrder(kcombobox, kintspinbox);
        QWidget::setTabOrder(kintspinbox, flatCheckBox);
        QWidget::setTabOrder(flatCheckBox, textedit);
        QWidget::setTabOrder(textedit, wrapCheckBox);

        retranslateUi(InputDemoWidget);

        QMetaObject::connectSlotsByName(InputDemoWidget);
    } // setupUi

    void retranslateUi(QWidget *InputDemoWidget)
    {
        label->setText(tr2i18n("Single line text editor:", nullptr));
        klineedit->setText(QString());
        label_2->setText(tr2i18n("Password editor:", nullptr));
        label_3->setText(tr2i18n("Editable combobox", nullptr));
        kcombobox->setItemText(0, tr2i18n("First item", nullptr));
        kcombobox->setItemText(1, tr2i18n("Second item", nullptr));
        kcombobox->setItemText(2, tr2i18n("Third item", nullptr));

        label_4->setText(tr2i18n("Spinbox:", nullptr));
        label_5->setText(tr2i18n("Multi-line text editor:", nullptr));
        wrapCheckBox->setText(tr2i18n("Wrap words", nullptr));
        flatCheckBox->setText(tr2i18n("Use flat widgets", nullptr));
        (void)InputDemoWidget;
    } // retranslateUi

};

namespace Ui {
    class InputDemoWidget: public Ui_InputDemoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENINPUTDEMOWIDGET_H

