// This file is generated by kconfig_compiler_kf5 from oxygen.kcfg.
// All changes you do to this file will be lost.
#ifndef OXYGEN_STYLECONFIGDATA_H
#define OXYGEN_STYLECONFIGDATA_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace Oxygen {

class StyleConfigData : public KConfigSkeleton
{
  public:
    enum EnumMnemonicsMode { MN_NEVER, MN_AUTO, MN_ALWAYS };
    enum EnumViewTriangularExpanderSize { TE_TINY, TE_SMALL, TE_NORMAL };
    enum EnumMenuHighlightMode { MM_DARK, MM_SUBTLE, MM_STRONG };
    enum EnumWindowDragMode { WD_NONE, WD_MINIMAL, WD_FULL };
    enum EnumToolBarAnimationType { TB_NONE, TB_FADE, TB_FOLLOW_MOUSE };
    enum EnumMenuBarAnimationType { MB_NONE, MB_FADE, MB_FOLLOW_MOUSE };
    enum EnumMenuAnimationType { ME_NONE, ME_FADE, ME_FOLLOW_MOUSE };

    static StyleConfigData *self();
    ~StyleConfigData() override;

    /**
      Set UseBackgroundGradient
    */
    static
    void setUseBackgroundGradient( bool v )
    {
      if (!self()->isUseBackgroundGradientImmutable())
        self()->mUseBackgroundGradient = v;
    }

    /**
      Get UseBackgroundGradient
    */
    static
    bool useBackgroundGradient()
    {
      return self()->mUseBackgroundGradient;
    }

    /**
      Is UseBackgroundGradient Immutable
    */
    static
    bool isUseBackgroundGradientImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseBackgroundGradient" ) );
    }

    /**
      Set CacheEnabled
    */
    static
    void setCacheEnabled( bool v )
    {
      if (!self()->isCacheEnabledImmutable())
        self()->mCacheEnabled = v;
    }

    /**
      Get CacheEnabled
    */
    static
    bool cacheEnabled()
    {
      return self()->mCacheEnabled;
    }

    /**
      Is CacheEnabled Immutable
    */
    static
    bool isCacheEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "CacheEnabled" ) );
    }

    /**
      Set MaxCacheSize
    */
    static
    void setMaxCacheSize( int v )
    {
      if (!self()->isMaxCacheSizeImmutable())
        self()->mMaxCacheSize = v;
    }

    /**
      Get MaxCacheSize
    */
    static
    int maxCacheSize()
    {
      return self()->mMaxCacheSize;
    }

    /**
      Is MaxCacheSize Immutable
    */
    static
    bool isMaxCacheSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MaxCacheSize" ) );
    }

    /**
      Set AnimationSteps
    */
    static
    void setAnimationSteps( int v )
    {
      if (!self()->isAnimationStepsImmutable())
        self()->mAnimationSteps = v;
    }

    /**
      Get AnimationSteps
    */
    static
    int animationSteps()
    {
      return self()->mAnimationSteps;
    }

    /**
      Is AnimationSteps Immutable
    */
    static
    bool isAnimationStepsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AnimationSteps" ) );
    }

    /**
      Set MnemonicsMode
    */
    static
    void setMnemonicsMode( int v )
    {
      if (!self()->isMnemonicsModeImmutable())
        self()->mMnemonicsMode = v;
    }

    /**
      Get MnemonicsMode
    */
    static
    int mnemonicsMode()
    {
      return self()->mMnemonicsMode;
    }

    /**
      Is MnemonicsMode Immutable
    */
    static
    bool isMnemonicsModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MnemonicsMode" ) );
    }

    /**
      Set SliderDrawTickMarks
    */
    static
    void setSliderDrawTickMarks( bool v )
    {
      if (!self()->isSliderDrawTickMarksImmutable())
        self()->mSliderDrawTickMarks = v;
    }

    /**
      Get SliderDrawTickMarks
    */
    static
    bool sliderDrawTickMarks()
    {
      return self()->mSliderDrawTickMarks;
    }

    /**
      Is SliderDrawTickMarks Immutable
    */
    static
    bool isSliderDrawTickMarksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SliderDrawTickMarks" ) );
    }

    /**
      Set ToolTipTransparent
    */
    static
    void setToolTipTransparent( bool v )
    {
      if (!self()->isToolTipTransparentImmutable())
        self()->mToolTipTransparent = v;
    }

    /**
      Get ToolTipTransparent
    */
    static
    bool toolTipTransparent()
    {
      return self()->mToolTipTransparent;
    }

    /**
      Is ToolTipTransparent Immutable
    */
    static
    bool isToolTipTransparentImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ToolTipTransparent" ) );
    }

    /**
      Set ToolBarDrawItemSeparator
    */
    static
    void setToolBarDrawItemSeparator( bool v )
    {
      if (!self()->isToolBarDrawItemSeparatorImmutable())
        self()->mToolBarDrawItemSeparator = v;
    }

    /**
      Get ToolBarDrawItemSeparator
    */
    static
    bool toolBarDrawItemSeparator()
    {
      return self()->mToolBarDrawItemSeparator;
    }

    /**
      Is ToolBarDrawItemSeparator Immutable
    */
    static
    bool isToolBarDrawItemSeparatorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ToolBarDrawItemSeparator" ) );
    }

    /**
      Set ViewDrawFocusIndicator
    */
    static
    void setViewDrawFocusIndicator( bool v )
    {
      if (!self()->isViewDrawFocusIndicatorImmutable())
        self()->mViewDrawFocusIndicator = v;
    }

    /**
      Get ViewDrawFocusIndicator
    */
    static
    bool viewDrawFocusIndicator()
    {
      return self()->mViewDrawFocusIndicator;
    }

    /**
      Is ViewDrawFocusIndicator Immutable
    */
    static
    bool isViewDrawFocusIndicatorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ViewDrawFocusIndicator" ) );
    }

    /**
      Set ViewTriangularExpanderSize
    */
    static
    void setViewTriangularExpanderSize( int v )
    {
      if (!self()->isViewTriangularExpanderSizeImmutable())
        self()->mViewTriangularExpanderSize = v;
    }

    /**
      Get ViewTriangularExpanderSize
    */
    static
    int viewTriangularExpanderSize()
    {
      return self()->mViewTriangularExpanderSize;
    }

    /**
      Is ViewTriangularExpanderSize Immutable
    */
    static
    bool isViewTriangularExpanderSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ViewTriangularExpanderSize" ) );
    }

    /**
      Set ViewDrawTreeBranchLines
    */
    static
    void setViewDrawTreeBranchLines( bool v )
    {
      if (!self()->isViewDrawTreeBranchLinesImmutable())
        self()->mViewDrawTreeBranchLines = v;
    }

    /**
      Get ViewDrawTreeBranchLines
    */
    static
    bool viewDrawTreeBranchLines()
    {
      return self()->mViewDrawTreeBranchLines;
    }

    /**
      Is ViewDrawTreeBranchLines Immutable
    */
    static
    bool isViewDrawTreeBranchLinesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ViewDrawTreeBranchLines" ) );
    }

    /**
      Set ViewInvertSortIndicator
    */
    static
    void setViewInvertSortIndicator( bool v )
    {
      if (!self()->isViewInvertSortIndicatorImmutable())
        self()->mViewInvertSortIndicator = v;
    }

    /**
      Get ViewInvertSortIndicator
    */
    static
    bool viewInvertSortIndicator()
    {
      return self()->mViewInvertSortIndicator;
    }

    /**
      Is ViewInvertSortIndicator Immutable
    */
    static
    bool isViewInvertSortIndicatorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ViewInvertSortIndicator" ) );
    }

    /**
      Set ScrollBarWidth
    */
    static
    void setScrollBarWidth( int v )
    {
      if (!self()->isScrollBarWidthImmutable())
        self()->mScrollBarWidth = v;
    }

    /**
      Get ScrollBarWidth
    */
    static
    int scrollBarWidth()
    {
      return self()->mScrollBarWidth;
    }

    /**
      Is ScrollBarWidth Immutable
    */
    static
    bool isScrollBarWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ScrollBarWidth" ) );
    }

    /**
      Set ScrollBarAddLineButtons
    */
    static
    void setScrollBarAddLineButtons( int v )
    {
      if (!self()->isScrollBarAddLineButtonsImmutable())
        self()->mScrollBarAddLineButtons = v;
    }

    /**
      Get ScrollBarAddLineButtons
    */
    static
    int scrollBarAddLineButtons()
    {
      return self()->mScrollBarAddLineButtons;
    }

    /**
      Is ScrollBarAddLineButtons Immutable
    */
    static
    bool isScrollBarAddLineButtonsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ScrollBarAddLineButtons" ) );
    }

    /**
      Set ScrollBarSubLineButtons
    */
    static
    void setScrollBarSubLineButtons( int v )
    {
      if (!self()->isScrollBarSubLineButtonsImmutable())
        self()->mScrollBarSubLineButtons = v;
    }

    /**
      Get ScrollBarSubLineButtons
    */
    static
    int scrollBarSubLineButtons()
    {
      return self()->mScrollBarSubLineButtons;
    }

    /**
      Is ScrollBarSubLineButtons Immutable
    */
    static
    bool isScrollBarSubLineButtonsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ScrollBarSubLineButtons" ) );
    }

    /**
      Set ProgressBarAnimated
    */
    static
    void setProgressBarAnimated( bool v )
    {
      if (!self()->isProgressBarAnimatedImmutable())
        self()->mProgressBarAnimated = v;
    }

    /**
      Get ProgressBarAnimated
    */
    static
    bool progressBarAnimated()
    {
      return self()->mProgressBarAnimated;
    }

    /**
      Is ProgressBarAnimated Immutable
    */
    static
    bool isProgressBarAnimatedImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProgressBarAnimated" ) );
    }

    /**
      Set MenuHighlightMode
    */
    static
    void setMenuHighlightMode( int v )
    {
      if (!self()->isMenuHighlightModeImmutable())
        self()->mMenuHighlightMode = v;
    }

    /**
      Get MenuHighlightMode
    */
    static
    int menuHighlightMode()
    {
      return self()->mMenuHighlightMode;
    }

    /**
      Is MenuHighlightMode Immutable
    */
    static
    bool isMenuHighlightModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MenuHighlightMode" ) );
    }

    /**
      Set WindowDragEnabled
    */
    static
    void setWindowDragEnabled( bool v )
    {
      if (!self()->isWindowDragEnabledImmutable())
        self()->mWindowDragEnabled = v;
    }

    /**
      Get WindowDragEnabled
    */
    static
    bool windowDragEnabled()
    {
      return self()->mWindowDragEnabled;
    }

    /**
      Is WindowDragEnabled Immutable
    */
    static
    bool isWindowDragEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WindowDragEnabled" ) );
    }

    /**
      Set WindowDragMode
    */
    static
    void setWindowDragMode( int v )
    {
      if (!self()->isWindowDragModeImmutable())
        self()->mWindowDragMode = v;
    }

    /**
      Get WindowDragMode
    */
    static
    int windowDragMode()
    {
      return self()->mWindowDragMode;
    }

    /**
      Is WindowDragMode Immutable
    */
    static
    bool isWindowDragModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WindowDragMode" ) );
    }

    /**
      Set SplitterProxyEnabled
    */
    static
    void setSplitterProxyEnabled( bool v )
    {
      if (!self()->isSplitterProxyEnabledImmutable())
        self()->mSplitterProxyEnabled = v;
    }

    /**
      Get SplitterProxyEnabled
    */
    static
    bool splitterProxyEnabled()
    {
      return self()->mSplitterProxyEnabled;
    }

    /**
      Is SplitterProxyEnabled Immutable
    */
    static
    bool isSplitterProxyEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SplitterProxyEnabled" ) );
    }

    /**
      Set SplitterProxyWidth
    */
    static
    void setSplitterProxyWidth( int v )
    {
      if (!self()->isSplitterProxyWidthImmutable())
        self()->mSplitterProxyWidth = v;
    }

    /**
      Get SplitterProxyWidth
    */
    static
    int splitterProxyWidth()
    {
      return self()->mSplitterProxyWidth;
    }

    /**
      Is SplitterProxyWidth Immutable
    */
    static
    bool isSplitterProxyWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SplitterProxyWidth" ) );
    }

    /**
      Set WidgetExplorerEnabled
    */
    static
    void setWidgetExplorerEnabled( bool v )
    {
      if (!self()->isWidgetExplorerEnabledImmutable())
        self()->mWidgetExplorerEnabled = v;
    }

    /**
      Get WidgetExplorerEnabled
    */
    static
    bool widgetExplorerEnabled()
    {
      return self()->mWidgetExplorerEnabled;
    }

    /**
      Is WidgetExplorerEnabled Immutable
    */
    static
    bool isWidgetExplorerEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WidgetExplorerEnabled" ) );
    }

    /**
      Set DrawWidgetRects
    */
    static
    void setDrawWidgetRects( bool v )
    {
      if (!self()->isDrawWidgetRectsImmutable())
        self()->mDrawWidgetRects = v;
    }

    /**
      Get DrawWidgetRects
    */
    static
    bool drawWidgetRects()
    {
      return self()->mDrawWidgetRects;
    }

    /**
      Is DrawWidgetRects Immutable
    */
    static
    bool isDrawWidgetRectsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DrawWidgetRects" ) );
    }

    /**
      Set WindowDragWhiteList
    */
    static
    void setWindowDragWhiteList( const QStringList & v )
    {
      if (!self()->isWindowDragWhiteListImmutable())
        self()->mWindowDragWhiteList = v;
    }

    /**
      Get WindowDragWhiteList
    */
    static
    QStringList windowDragWhiteList()
    {
      return self()->mWindowDragWhiteList;
    }

    /**
      Is WindowDragWhiteList Immutable
    */
    static
    bool isWindowDragWhiteListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WindowDragWhiteList" ) );
    }

    /**
      Set WindowDragBlackList
    */
    static
    void setWindowDragBlackList( const QStringList & v )
    {
      if (!self()->isWindowDragBlackListImmutable())
        self()->mWindowDragBlackList = v;
    }

    /**
      Get WindowDragBlackList
    */
    static
    QStringList windowDragBlackList()
    {
      return self()->mWindowDragBlackList;
    }

    /**
      Is WindowDragBlackList Immutable
    */
    static
    bool isWindowDragBlackListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "WindowDragBlackList" ) );
    }

    /**
      Set UseWMMoveResize
    */
    static
    void setUseWMMoveResize( bool v )
    {
      if (!self()->isUseWMMoveResizeImmutable())
        self()->mUseWMMoveResize = v;
    }

    /**
      Get UseWMMoveResize
    */
    static
    bool useWMMoveResize()
    {
      return self()->mUseWMMoveResize;
    }

    /**
      Is UseWMMoveResize Immutable
    */
    static
    bool isUseWMMoveResizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "UseWMMoveResize" ) );
    }

    /**
      Set AnimationsEnabled
    */
    static
    void setAnimationsEnabled( bool v )
    {
      if (!self()->isAnimationsEnabledImmutable())
        self()->mAnimationsEnabled = v;
    }

    /**
      Get AnimationsEnabled
    */
    static
    bool animationsEnabled()
    {
      return self()->mAnimationsEnabled;
    }

    /**
      Is AnimationsEnabled Immutable
    */
    static
    bool isAnimationsEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AnimationsEnabled" ) );
    }

    /**
      Set GenericAnimationsEnabled
    */
    static
    void setGenericAnimationsEnabled( bool v )
    {
      if (!self()->isGenericAnimationsEnabledImmutable())
        self()->mGenericAnimationsEnabled = v;
    }

    /**
      Get GenericAnimationsEnabled
    */
    static
    bool genericAnimationsEnabled()
    {
      return self()->mGenericAnimationsEnabled;
    }

    /**
      Is GenericAnimationsEnabled Immutable
    */
    static
    bool isGenericAnimationsEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GenericAnimationsEnabled" ) );
    }

    /**
      Set ToolBarAnimationType
    */
    static
    void setToolBarAnimationType( int v )
    {
      if (!self()->isToolBarAnimationTypeImmutable())
        self()->mToolBarAnimationType = v;
    }

    /**
      Get ToolBarAnimationType
    */
    static
    int toolBarAnimationType()
    {
      return self()->mToolBarAnimationType;
    }

    /**
      Is ToolBarAnimationType Immutable
    */
    static
    bool isToolBarAnimationTypeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ToolBarAnimationType" ) );
    }

    /**
      Set MenuBarAnimationType
    */
    static
    void setMenuBarAnimationType( int v )
    {
      if (!self()->isMenuBarAnimationTypeImmutable())
        self()->mMenuBarAnimationType = v;
    }

    /**
      Get MenuBarAnimationType
    */
    static
    int menuBarAnimationType()
    {
      return self()->mMenuBarAnimationType;
    }

    /**
      Is MenuBarAnimationType Immutable
    */
    static
    bool isMenuBarAnimationTypeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MenuBarAnimationType" ) );
    }

    /**
      Set MenuAnimationType
    */
    static
    void setMenuAnimationType( int v )
    {
      if (!self()->isMenuAnimationTypeImmutable())
        self()->mMenuAnimationType = v;
    }

    /**
      Get MenuAnimationType
    */
    static
    int menuAnimationType()
    {
      return self()->mMenuAnimationType;
    }

    /**
      Is MenuAnimationType Immutable
    */
    static
    bool isMenuAnimationTypeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MenuAnimationType" ) );
    }

    /**
      Set ProgressBarAnimationsEnabled
    */
    static
    void setProgressBarAnimationsEnabled( bool v )
    {
      if (!self()->isProgressBarAnimationsEnabledImmutable())
        self()->mProgressBarAnimationsEnabled = v;
    }

    /**
      Get ProgressBarAnimationsEnabled
    */
    static
    bool progressBarAnimationsEnabled()
    {
      return self()->mProgressBarAnimationsEnabled;
    }

    /**
      Is ProgressBarAnimationsEnabled Immutable
    */
    static
    bool isProgressBarAnimationsEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProgressBarAnimationsEnabled" ) );
    }

    /**
      Set GenericAnimationsDuration
    */
    static
    void setGenericAnimationsDuration( int v )
    {
      if (!self()->isGenericAnimationsDurationImmutable())
        self()->mGenericAnimationsDuration = v;
    }

    /**
      Get GenericAnimationsDuration
    */
    static
    int genericAnimationsDuration()
    {
      return self()->mGenericAnimationsDuration;
    }

    /**
      Is GenericAnimationsDuration Immutable
    */
    static
    bool isGenericAnimationsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "GenericAnimationsDuration" ) );
    }

    /**
      Set ToolBarAnimationsDuration
    */
    static
    void setToolBarAnimationsDuration( int v )
    {
      if (!self()->isToolBarAnimationsDurationImmutable())
        self()->mToolBarAnimationsDuration = v;
    }

    /**
      Get ToolBarAnimationsDuration
    */
    static
    int toolBarAnimationsDuration()
    {
      return self()->mToolBarAnimationsDuration;
    }

    /**
      Is ToolBarAnimationsDuration Immutable
    */
    static
    bool isToolBarAnimationsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ToolBarAnimationsDuration" ) );
    }

    /**
      Set MenuBarAnimationsDuration
    */
    static
    void setMenuBarAnimationsDuration( int v )
    {
      if (!self()->isMenuBarAnimationsDurationImmutable())
        self()->mMenuBarAnimationsDuration = v;
    }

    /**
      Get MenuBarAnimationsDuration
    */
    static
    int menuBarAnimationsDuration()
    {
      return self()->mMenuBarAnimationsDuration;
    }

    /**
      Is MenuBarAnimationsDuration Immutable
    */
    static
    bool isMenuBarAnimationsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MenuBarAnimationsDuration" ) );
    }

    /**
      Set MenuBarFollowMouseAnimationsDuration
    */
    static
    void setMenuBarFollowMouseAnimationsDuration( int v )
    {
      if (!self()->isMenuBarFollowMouseAnimationsDurationImmutable())
        self()->mMenuBarFollowMouseAnimationsDuration = v;
    }

    /**
      Get MenuBarFollowMouseAnimationsDuration
    */
    static
    int menuBarFollowMouseAnimationsDuration()
    {
      return self()->mMenuBarFollowMouseAnimationsDuration;
    }

    /**
      Is MenuBarFollowMouseAnimationsDuration Immutable
    */
    static
    bool isMenuBarFollowMouseAnimationsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MenuBarFollowMouseAnimationsDuration" ) );
    }

    /**
      Set MenuAnimationsDuration
    */
    static
    void setMenuAnimationsDuration( int v )
    {
      if (!self()->isMenuAnimationsDurationImmutable())
        self()->mMenuAnimationsDuration = v;
    }

    /**
      Get MenuAnimationsDuration
    */
    static
    int menuAnimationsDuration()
    {
      return self()->mMenuAnimationsDuration;
    }

    /**
      Is MenuAnimationsDuration Immutable
    */
    static
    bool isMenuAnimationsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MenuAnimationsDuration" ) );
    }

    /**
      Set MenuFollowMouseAnimationsDuration
    */
    static
    void setMenuFollowMouseAnimationsDuration( int v )
    {
      if (!self()->isMenuFollowMouseAnimationsDurationImmutable())
        self()->mMenuFollowMouseAnimationsDuration = v;
    }

    /**
      Get MenuFollowMouseAnimationsDuration
    */
    static
    int menuFollowMouseAnimationsDuration()
    {
      return self()->mMenuFollowMouseAnimationsDuration;
    }

    /**
      Is MenuFollowMouseAnimationsDuration Immutable
    */
    static
    bool isMenuFollowMouseAnimationsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "MenuFollowMouseAnimationsDuration" ) );
    }

    /**
      Set ProgressBarAnimationsDuration
    */
    static
    void setProgressBarAnimationsDuration( int v )
    {
      if (!self()->isProgressBarAnimationsDurationImmutable())
        self()->mProgressBarAnimationsDuration = v;
    }

    /**
      Get ProgressBarAnimationsDuration
    */
    static
    int progressBarAnimationsDuration()
    {
      return self()->mProgressBarAnimationsDuration;
    }

    /**
      Is ProgressBarAnimationsDuration Immutable
    */
    static
    bool isProgressBarAnimationsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProgressBarAnimationsDuration" ) );
    }

    /**
      Set ProgressBarBusyStepDuration
    */
    static
    void setProgressBarBusyStepDuration( int v )
    {
      if (!self()->isProgressBarBusyStepDurationImmutable())
        self()->mProgressBarBusyStepDuration = v;
    }

    /**
      Get ProgressBarBusyStepDuration
    */
    static
    int progressBarBusyStepDuration()
    {
      return self()->mProgressBarBusyStepDuration;
    }

    /**
      Is ProgressBarBusyStepDuration Immutable
    */
    static
    bool isProgressBarBusyStepDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ProgressBarBusyStepDuration" ) );
    }

    /**
      Set StackedWidgetTransitionsEnabled
    */
    static
    void setStackedWidgetTransitionsEnabled( bool v )
    {
      if (!self()->isStackedWidgetTransitionsEnabledImmutable())
        self()->mStackedWidgetTransitionsEnabled = v;
    }

    /**
      Get StackedWidgetTransitionsEnabled
    */
    static
    bool stackedWidgetTransitionsEnabled()
    {
      return self()->mStackedWidgetTransitionsEnabled;
    }

    /**
      Is StackedWidgetTransitionsEnabled Immutable
    */
    static
    bool isStackedWidgetTransitionsEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "StackedWidgetTransitionsEnabled" ) );
    }

    /**
      Set LabelTransitionsEnabled
    */
    static
    void setLabelTransitionsEnabled( bool v )
    {
      if (!self()->isLabelTransitionsEnabledImmutable())
        self()->mLabelTransitionsEnabled = v;
    }

    /**
      Get LabelTransitionsEnabled
    */
    static
    bool labelTransitionsEnabled()
    {
      return self()->mLabelTransitionsEnabled;
    }

    /**
      Is LabelTransitionsEnabled Immutable
    */
    static
    bool isLabelTransitionsEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LabelTransitionsEnabled" ) );
    }

    /**
      Set ComboBoxTransitionsEnabled
    */
    static
    void setComboBoxTransitionsEnabled( bool v )
    {
      if (!self()->isComboBoxTransitionsEnabledImmutable())
        self()->mComboBoxTransitionsEnabled = v;
    }

    /**
      Get ComboBoxTransitionsEnabled
    */
    static
    bool comboBoxTransitionsEnabled()
    {
      return self()->mComboBoxTransitionsEnabled;
    }

    /**
      Is ComboBoxTransitionsEnabled Immutable
    */
    static
    bool isComboBoxTransitionsEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ComboBoxTransitionsEnabled" ) );
    }

    /**
      Set LineEditTransitionsEnabled
    */
    static
    void setLineEditTransitionsEnabled( bool v )
    {
      if (!self()->isLineEditTransitionsEnabledImmutable())
        self()->mLineEditTransitionsEnabled = v;
    }

    /**
      Get LineEditTransitionsEnabled
    */
    static
    bool lineEditTransitionsEnabled()
    {
      return self()->mLineEditTransitionsEnabled;
    }

    /**
      Is LineEditTransitionsEnabled Immutable
    */
    static
    bool isLineEditTransitionsEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LineEditTransitionsEnabled" ) );
    }

    /**
      Set StackedWidgetTransitionsDuration
    */
    static
    void setStackedWidgetTransitionsDuration( int v )
    {
      if (!self()->isStackedWidgetTransitionsDurationImmutable())
        self()->mStackedWidgetTransitionsDuration = v;
    }

    /**
      Get StackedWidgetTransitionsDuration
    */
    static
    int stackedWidgetTransitionsDuration()
    {
      return self()->mStackedWidgetTransitionsDuration;
    }

    /**
      Is StackedWidgetTransitionsDuration Immutable
    */
    static
    bool isStackedWidgetTransitionsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "StackedWidgetTransitionsDuration" ) );
    }

    /**
      Set LabelTransitionsDuration
    */
    static
    void setLabelTransitionsDuration( int v )
    {
      if (!self()->isLabelTransitionsDurationImmutable())
        self()->mLabelTransitionsDuration = v;
    }

    /**
      Get LabelTransitionsDuration
    */
    static
    int labelTransitionsDuration()
    {
      return self()->mLabelTransitionsDuration;
    }

    /**
      Is LabelTransitionsDuration Immutable
    */
    static
    bool isLabelTransitionsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LabelTransitionsDuration" ) );
    }

    /**
      Set ComboBoxTransitionsDuration
    */
    static
    void setComboBoxTransitionsDuration( int v )
    {
      if (!self()->isComboBoxTransitionsDurationImmutable())
        self()->mComboBoxTransitionsDuration = v;
    }

    /**
      Get ComboBoxTransitionsDuration
    */
    static
    int comboBoxTransitionsDuration()
    {
      return self()->mComboBoxTransitionsDuration;
    }

    /**
      Is ComboBoxTransitionsDuration Immutable
    */
    static
    bool isComboBoxTransitionsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ComboBoxTransitionsDuration" ) );
    }

    /**
      Set LineEditTransitionsDuration
    */
    static
    void setLineEditTransitionsDuration( int v )
    {
      if (!self()->isLineEditTransitionsDurationImmutable())
        self()->mLineEditTransitionsDuration = v;
    }

    /**
      Get LineEditTransitionsDuration
    */
    static
    int lineEditTransitionsDuration()
    {
      return self()->mLineEditTransitionsDuration;
    }

    /**
      Is LineEditTransitionsDuration Immutable
    */
    static
    bool isLineEditTransitionsDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LineEditTransitionsDuration" ) );
    }

  protected:
    StyleConfigData();
    friend class StyleConfigDataHelper;


    // Common
    bool mUseBackgroundGradient;

    // Style
    bool mCacheEnabled;
    int mMaxCacheSize;
    int mAnimationSteps;
    int mMnemonicsMode;
    bool mSliderDrawTickMarks;
    bool mToolTipTransparent;
    bool mToolBarDrawItemSeparator;
    bool mViewDrawFocusIndicator;
    int mViewTriangularExpanderSize;
    bool mViewDrawTreeBranchLines;
    bool mViewInvertSortIndicator;
    int mScrollBarWidth;
    int mScrollBarAddLineButtons;
    int mScrollBarSubLineButtons;
    bool mProgressBarAnimated;
    int mMenuHighlightMode;
    bool mWindowDragEnabled;
    int mWindowDragMode;
    bool mSplitterProxyEnabled;
    int mSplitterProxyWidth;
    bool mWidgetExplorerEnabled;
    bool mDrawWidgetRects;
    QStringList mWindowDragWhiteList;
    QStringList mWindowDragBlackList;
    bool mUseWMMoveResize;
    bool mAnimationsEnabled;
    bool mGenericAnimationsEnabled;
    int mToolBarAnimationType;
    int mMenuBarAnimationType;
    int mMenuAnimationType;
    bool mProgressBarAnimationsEnabled;
    int mGenericAnimationsDuration;
    int mToolBarAnimationsDuration;
    int mMenuBarAnimationsDuration;
    int mMenuBarFollowMouseAnimationsDuration;
    int mMenuAnimationsDuration;
    int mMenuFollowMouseAnimationsDuration;
    int mProgressBarAnimationsDuration;
    int mProgressBarBusyStepDuration;
    bool mStackedWidgetTransitionsEnabled;
    bool mLabelTransitionsEnabled;
    bool mComboBoxTransitionsEnabled;
    bool mLineEditTransitionsEnabled;
    int mStackedWidgetTransitionsDuration;
    int mLabelTransitionsDuration;
    int mComboBoxTransitionsDuration;
    int mLineEditTransitionsDuration;

  private:
};

}

#endif

