#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'oxygengenericanimationconfigbox.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENGENERICANIMATIONCONFIGBOX_H
#define UI_OXYGENGENERICANIMATIONCONFIGBOX_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_GenericAnimationConfigBox
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QSpinBox *durationSpinBox;

    void setupUi(QFrame *GenericAnimationConfigBox)
    {
        if (GenericAnimationConfigBox->objectName().isEmpty())
            GenericAnimationConfigBox->setObjectName(QString::fromUtf8("GenericAnimationConfigBox"));
        GenericAnimationConfigBox->resize(400, 38);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GenericAnimationConfigBox->sizePolicy().hasHeightForWidth());
        GenericAnimationConfigBox->setSizePolicy(sizePolicy);
        GenericAnimationConfigBox->setFrameShape(QFrame::StyledPanel);
        GenericAnimationConfigBox->setFrameShadow(QFrame::Sunken);
        gridLayout = new QGridLayout(GenericAnimationConfigBox);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(GenericAnimationConfigBox);
        label->setObjectName(QString::fromUtf8("label"));
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        durationSpinBox = new QSpinBox(GenericAnimationConfigBox);
        durationSpinBox->setObjectName(QString::fromUtf8("durationSpinBox"));
        durationSpinBox->setMinimum(5);
        durationSpinBox->setMaximum(2000);
        durationSpinBox->setSingleStep(5);

        gridLayout->addWidget(durationSpinBox, 0, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(durationSpinBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GenericAnimationConfigBox);

        QMetaObject::connectSlotsByName(GenericAnimationConfigBox);
    } // setupUi

    void retranslateUi(QFrame *GenericAnimationConfigBox)
    {
        GenericAnimationConfigBox->setWindowTitle(tr2i18n("Frame", nullptr));
        label->setText(tr2i18n("Duration:", nullptr));
        durationSpinBox->setSuffix(tr2i18n(" ms", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GenericAnimationConfigBox: public Ui_GenericAnimationConfigBox {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENGENERICANIMATIONCONFIGBOX_H

