/********************************************************************************
** Form generated from reading UI file 'oxygensliderdemowidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENSLIDERDEMOWIDGET_H
#define UI_OXYGENSLIDERDEMOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDial>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QScrollBar>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SliderDemoWidget
{
public:
    QGridLayout *gridLayout;
    QCheckBox *animateProgressBarCheckBox;
    QCheckBox *invertProgressBarCheckBox;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QSlider *horizontalSlider;
    QProgressBar *horizontalProgressBar;
    QScrollBar *horizontalScrollBar;
    QDial *dial;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_2;
    QSlider *verticalSlider;
    QProgressBar *verticalProgressBar;
    QScrollBar *verticalScrollBar;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *tickPositionComboBox;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *SliderDemoWidget)
    {
        if (SliderDemoWidget->objectName().isEmpty())
            SliderDemoWidget->setObjectName("SliderDemoWidget");
        SliderDemoWidget->resize(540, 356);
        gridLayout = new QGridLayout(SliderDemoWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        animateProgressBarCheckBox = new QCheckBox(SliderDemoWidget);
        animateProgressBarCheckBox->setObjectName("animateProgressBarCheckBox");

        gridLayout->addWidget(animateProgressBarCheckBox, 0, 0, 1, 1);

        invertProgressBarCheckBox = new QCheckBox(SliderDemoWidget);
        invertProgressBarCheckBox->setObjectName("invertProgressBarCheckBox");

        gridLayout->addWidget(invertProgressBarCheckBox, 1, 0, 1, 1);

        groupBox = new QGroupBox(SliderDemoWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        horizontalSlider = new QSlider(groupBox);
        horizontalSlider->setObjectName("horizontalSlider");
        horizontalSlider->setMaximum(100);
        horizontalSlider->setValue(25);
        horizontalSlider->setOrientation(Qt::Horizontal);
        horizontalSlider->setTickPosition(QSlider::NoTicks);

        verticalLayout->addWidget(horizontalSlider);

        horizontalProgressBar = new QProgressBar(groupBox);
        horizontalProgressBar->setObjectName("horizontalProgressBar");
        horizontalProgressBar->setValue(25);
        horizontalProgressBar->setTextVisible(true);

        verticalLayout->addWidget(horizontalProgressBar);

        horizontalScrollBar = new QScrollBar(groupBox);
        horizontalScrollBar->setObjectName("horizontalScrollBar");
        horizontalScrollBar->setMaximum(100);
        horizontalScrollBar->setValue(25);
        horizontalScrollBar->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalScrollBar);

        dial = new QDial(groupBox);
        dial->setObjectName("dial");
        dial->setMaximum(100);
        dial->setValue(25);
        dial->setWrapping(false);
        dial->setNotchesVisible(false);

        verticalLayout->addWidget(dial);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addWidget(groupBox, 3, 0, 1, 1);

        groupBox_2 = new QGroupBox(SliderDemoWidget);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_2 = new QHBoxLayout(groupBox_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalSlider = new QSlider(groupBox_2);
        verticalSlider->setObjectName("verticalSlider");
        verticalSlider->setMaximum(100);
        verticalSlider->setValue(25);
        verticalSlider->setOrientation(Qt::Vertical);

        horizontalLayout_2->addWidget(verticalSlider);

        verticalProgressBar = new QProgressBar(groupBox_2);
        verticalProgressBar->setObjectName("verticalProgressBar");
        verticalProgressBar->setValue(25);
        verticalProgressBar->setOrientation(Qt::Vertical);

        horizontalLayout_2->addWidget(verticalProgressBar);

        verticalScrollBar = new QScrollBar(groupBox_2);
        verticalScrollBar->setObjectName("verticalScrollBar");
        verticalScrollBar->setMaximum(100);
        verticalScrollBar->setValue(25);
        verticalScrollBar->setOrientation(Qt::Vertical);

        horizontalLayout_2->addWidget(verticalScrollBar);


        gridLayout->addWidget(groupBox_2, 3, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SliderDemoWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        tickPositionComboBox = new QComboBox(SliderDemoWidget);
        tickPositionComboBox->addItem(QString());
        tickPositionComboBox->addItem(QString());
        tickPositionComboBox->addItem(QString());
        tickPositionComboBox->addItem(QString());
        tickPositionComboBox->setObjectName("tickPositionComboBox");
        tickPositionComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout->addWidget(tickPositionComboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 2, 0, 1, 2);

        QWidget::setTabOrder(animateProgressBarCheckBox, invertProgressBarCheckBox);
        QWidget::setTabOrder(invertProgressBarCheckBox, tickPositionComboBox);
        QWidget::setTabOrder(tickPositionComboBox, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, dial);
        QWidget::setTabOrder(dial, verticalSlider);

        retranslateUi(SliderDemoWidget);

        QMetaObject::connectSlotsByName(SliderDemoWidget);
    } // setupUi

    void retranslateUi(QWidget *SliderDemoWidget)
    {
        animateProgressBarCheckBox->setText(tr2i18n("Animate Progress Bars", nullptr));
        invertProgressBarCheckBox->setText(tr2i18n("Invert Progress Bars", nullptr));
        groupBox->setTitle(tr2i18n("Horizontal", nullptr));
        groupBox_2->setTitle(tr2i18n("Vertical", nullptr));
        label->setText(tr2i18n("Sliders tick marks position", nullptr));
        tickPositionComboBox->setItemText(0, tr2i18n("No Tick Marks", nullptr));
        tickPositionComboBox->setItemText(1, tr2i18n("Tick Marks Above Slider", nullptr));
        tickPositionComboBox->setItemText(2, tr2i18n("Tick Marks Below Slider", nullptr));
        tickPositionComboBox->setItemText(3, tr2i18n("Tick Marks On Both Sides", nullptr));

        (void)SliderDemoWidget;
    } // retranslateUi

};

namespace Ui {
    class SliderDemoWidget: public Ui_SliderDemoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENSLIDERDEMOWIDGET_H

