// This file is generated by kconfig_compiler_kf6 from oxygensettingsdata.kcfg.
// All changes you do to this file will be lost.

#include "oxygensettings.h"

using namespace Oxygen;

InternalSettings::InternalSettings( )
  : KConfigSkeleton( QStringLiteral( "oxygenrc" ) )
{
  setCurrentGroup( QStringLiteral( "Windeco" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesTitleAlignment;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("AlignLeft");
    valuesTitleAlignment.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("AlignCenter");
    valuesTitleAlignment.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("AlignCenterFullWidth");
    valuesTitleAlignment.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("AlignRight");
    valuesTitleAlignment.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemTitleAlignment;
  itemTitleAlignment = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "TitleAlignment" ), mTitleAlignment, valuesTitleAlignment, AlignCenterFullWidth );
  addItem( itemTitleAlignment, QStringLiteral( "TitleAlignment" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesButtonSize;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ButtonSmall");
    valuesButtonSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ButtonDefault");
    valuesButtonSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ButtonLarge");
    valuesButtonSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ButtonVeryLarge");
    valuesButtonSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ButtonHuge");
    valuesButtonSize.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemButtonSize;
  itemButtonSize = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "ButtonSize" ), mButtonSize, valuesButtonSize, ButtonDefault );
  addItem( itemButtonSize, QStringLiteral( "ButtonSize" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesBorderSize;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderNone");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderNoSides");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderTiny");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderNormal");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderLarge");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderVeryLarge");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderHuge");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderVeryHuge");
    valuesBorderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BorderOversized");
    valuesBorderSize.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemBorderSize;
  itemBorderSize = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "BorderSize" ), mBorderSize, valuesBorderSize, BorderNoSides );
  addItem( itemBorderSize, QStringLiteral( "BorderSize" ) );
  KConfigSkeleton::ItemBool  *itemUseWindowColors;
  itemUseWindowColors = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseWindowColors" ), mUseWindowColors, true );
  addItem( itemUseWindowColors, QStringLiteral( "UseWindowColors" ) );
  KConfigSkeleton::ItemBool  *itemHideTitleBar;
  itemHideTitleBar = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "HideTitleBar" ), mHideTitleBar, false );
  addItem( itemHideTitleBar, QStringLiteral( "HideTitleBar" ) );
  KConfigSkeleton::ItemBool  *itemDrawBorderOnMaximizedWindows;
  itemDrawBorderOnMaximizedWindows = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DrawBorderOnMaximizedWindows" ), mDrawBorderOnMaximizedWindows, false );
  addItem( itemDrawBorderOnMaximizedWindows, QStringLiteral( "DrawBorderOnMaximizedWindows" ) );
  KConfigSkeleton::ItemBool  *itemAnimationsEnabled;
  itemAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnimationsEnabled" ), mAnimationsEnabled, true );
  addItem( itemAnimationsEnabled, QStringLiteral( "AnimationsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemButtonAnimationsEnabled;
  itemButtonAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ButtonAnimationsEnabled" ), mButtonAnimationsEnabled, true );
  addItem( itemButtonAnimationsEnabled, QStringLiteral( "ButtonAnimationsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemTitleAnimationsEnabled;
  itemTitleAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TitleAnimationsEnabled" ), mTitleAnimationsEnabled, true );
  addItem( itemTitleAnimationsEnabled, QStringLiteral( "TitleAnimationsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemShadowAnimationsEnabled;
  itemShadowAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShadowAnimationsEnabled" ), mShadowAnimationsEnabled, true );
  addItem( itemShadowAnimationsEnabled, QStringLiteral( "ShadowAnimationsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemTabAnimationsEnabled;
  itemTabAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TabAnimationsEnabled" ), mTabAnimationsEnabled, true );
  addItem( itemTabAnimationsEnabled, QStringLiteral( "TabAnimationsEnabled" ) );
  KConfigSkeleton::ItemInt  *itemButtonAnimationsDuration;
  itemButtonAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ButtonAnimationsDuration" ), mButtonAnimationsDuration, 150 );
  addItem( itemButtonAnimationsDuration, QStringLiteral( "ButtonAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemTitleAnimationsDuration;
  itemTitleAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TitleAnimationsDuration" ), mTitleAnimationsDuration, 150 );
  addItem( itemTitleAnimationsDuration, QStringLiteral( "TitleAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemShadowAnimationsDuration;
  itemShadowAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ShadowAnimationsDuration" ), mShadowAnimationsDuration, 150 );
  addItem( itemShadowAnimationsDuration, QStringLiteral( "ShadowAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemTabAnimationsDuration;
  itemTabAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TabAnimationsDuration" ), mTabAnimationsDuration, 150 );
  addItem( itemTabAnimationsDuration, QStringLiteral( "TabAnimationsDuration" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesExceptionType;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ExceptionWindowClassName");
    valuesExceptionType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ExceptionWindowTitle");
    valuesExceptionType.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemExceptionType;
  itemExceptionType = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "ExceptionType" ), mExceptionType, valuesExceptionType, ExceptionWindowClassName );
  addItem( itemExceptionType, QStringLiteral( "ExceptionType" ) );
  KConfigSkeleton::ItemString  *itemExceptionPattern;
  itemExceptionPattern = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ExceptionPattern" ), mExceptionPattern );
  addItem( itemExceptionPattern, QStringLiteral( "ExceptionPattern" ) );
  KConfigSkeleton::ItemBool  *itemEnabled;
  itemEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Enabled" ), mEnabled, true );
  addItem( itemEnabled, QStringLiteral( "Enabled" ) );
  KConfigSkeleton::ItemInt  *itemMask;
  itemMask = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Mask" ), mMask, 0 );
  addItem( itemMask, QStringLiteral( "Mask" ) );
}

InternalSettings::~InternalSettings()
{
}

