// This file is generated by kconfig_compiler_kf5 from oxygen.kcfg.
// All changes you do to this file will be lost.

#include "oxygenstyleconfigdata.h"

#include <qglobal.h>
#include <QFile>

using namespace Oxygen;

namespace Oxygen {

class StyleConfigDataHelper
{
  public:
    StyleConfigDataHelper() : q(nullptr) {}
    ~StyleConfigDataHelper() { delete q; q = nullptr; }
    StyleConfigDataHelper(const StyleConfigDataHelper&) = delete;
    StyleConfigDataHelper& operator=(const StyleConfigDataHelper&) = delete;
    StyleConfigData *q;
};

}
Q_GLOBAL_STATIC(StyleConfigDataHelper, s_globalStyleConfigData)
StyleConfigData *StyleConfigData::self()
{
  if (!s_globalStyleConfigData()->q) {
    new StyleConfigData;
    s_globalStyleConfigData()->q->read();
  }

  return s_globalStyleConfigData()->q;
}

StyleConfigData::StyleConfigData( )
  : KConfigSkeleton( QStringLiteral( "oxygenrc" ) )
{
  Q_ASSERT(!s_globalStyleConfigData()->q);
  s_globalStyleConfigData()->q = this;
  setCurrentGroup( QStringLiteral( "Common" ) );

  KConfigSkeleton::ItemBool  *itemUseBackgroundGradient;
  itemUseBackgroundGradient = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseBackgroundGradient" ), mUseBackgroundGradient, true );
  addItem( itemUseBackgroundGradient, QStringLiteral( "UseBackgroundGradient" ) );

  setCurrentGroup( QStringLiteral( "Style" ) );

  KConfigSkeleton::ItemBool  *itemCacheEnabled;
  itemCacheEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CacheEnabled" ), mCacheEnabled, true );
  addItem( itemCacheEnabled, QStringLiteral( "CacheEnabled" ) );
  KConfigSkeleton::ItemInt  *itemMaxCacheSize;
  itemMaxCacheSize = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MaxCacheSize" ), mMaxCacheSize, 512 );
  addItem( itemMaxCacheSize, QStringLiteral( "MaxCacheSize" ) );
  KConfigSkeleton::ItemInt  *itemAnimationSteps;
  itemAnimationSteps = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AnimationSteps" ), mAnimationSteps, 10 );
  addItem( itemAnimationSteps, QStringLiteral( "AnimationSteps" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesMnemonicsMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MN_NEVER");
    valuesMnemonicsMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MN_AUTO");
    valuesMnemonicsMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MN_ALWAYS");
    valuesMnemonicsMode.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemMnemonicsMode;
  itemMnemonicsMode = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "MnemonicsMode" ), mMnemonicsMode, valuesMnemonicsMode, MN_ALWAYS );
  addItem( itemMnemonicsMode, QStringLiteral( "MnemonicsMode" ) );
  KConfigSkeleton::ItemBool  *itemSliderDrawTickMarks;
  itemSliderDrawTickMarks = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SliderDrawTickMarks" ), mSliderDrawTickMarks, true );
  addItem( itemSliderDrawTickMarks, QStringLiteral( "SliderDrawTickMarks" ) );
  KConfigSkeleton::ItemBool  *itemToolTipTransparent;
  itemToolTipTransparent = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ToolTipTransparent" ), mToolTipTransparent, true );
  addItem( itemToolTipTransparent, QStringLiteral( "ToolTipTransparent" ) );
  KConfigSkeleton::ItemBool  *itemToolBarDrawItemSeparator;
  itemToolBarDrawItemSeparator = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ToolBarDrawItemSeparator" ), mToolBarDrawItemSeparator, true );
  addItem( itemToolBarDrawItemSeparator, QStringLiteral( "ToolBarDrawItemSeparator" ) );
  KConfigSkeleton::ItemBool  *itemViewDrawFocusIndicator;
  itemViewDrawFocusIndicator = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ViewDrawFocusIndicator" ), mViewDrawFocusIndicator, false );
  addItem( itemViewDrawFocusIndicator, QStringLiteral( "ViewDrawFocusIndicator" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesViewTriangularExpanderSize;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TE_TINY");
    valuesViewTriangularExpanderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TE_SMALL");
    valuesViewTriangularExpanderSize.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TE_NORMAL");
    valuesViewTriangularExpanderSize.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemViewTriangularExpanderSize;
  itemViewTriangularExpanderSize = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "ViewTriangularExpanderSize" ), mViewTriangularExpanderSize, valuesViewTriangularExpanderSize, TE_SMALL );
  addItem( itemViewTriangularExpanderSize, QStringLiteral( "ViewTriangularExpanderSize" ) );
  KConfigSkeleton::ItemBool  *itemViewDrawTreeBranchLines;
  itemViewDrawTreeBranchLines = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ViewDrawTreeBranchLines" ), mViewDrawTreeBranchLines, true );
  addItem( itemViewDrawTreeBranchLines, QStringLiteral( "ViewDrawTreeBranchLines" ) );
  KConfigSkeleton::ItemBool  *itemViewInvertSortIndicator;
  itemViewInvertSortIndicator = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ViewInvertSortIndicator" ), mViewInvertSortIndicator, false );
  addItem( itemViewInvertSortIndicator, QStringLiteral( "ViewInvertSortIndicator" ) );
  KConfigSkeleton::ItemInt  *itemScrollBarWidth;
  itemScrollBarWidth = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ScrollBarWidth" ), mScrollBarWidth, 15 );
  addItem( itemScrollBarWidth, QStringLiteral( "ScrollBarWidth" ) );
  KConfigSkeleton::ItemInt  *itemScrollBarAddLineButtons;
  itemScrollBarAddLineButtons = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ScrollBarAddLineButtons" ), mScrollBarAddLineButtons, 2 );
  addItem( itemScrollBarAddLineButtons, QStringLiteral( "ScrollBarAddLineButtons" ) );
  KConfigSkeleton::ItemInt  *itemScrollBarSubLineButtons;
  itemScrollBarSubLineButtons = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ScrollBarSubLineButtons" ), mScrollBarSubLineButtons, 1 );
  addItem( itemScrollBarSubLineButtons, QStringLiteral( "ScrollBarSubLineButtons" ) );
  KConfigSkeleton::ItemBool  *itemProgressBarAnimated;
  itemProgressBarAnimated = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ProgressBarAnimated" ), mProgressBarAnimated, true );
  addItem( itemProgressBarAnimated, QStringLiteral( "ProgressBarAnimated" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesMenuHighlightMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MM_DARK");
    valuesMenuHighlightMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MM_SUBTLE");
    valuesMenuHighlightMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MM_STRONG");
    valuesMenuHighlightMode.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemMenuHighlightMode;
  itemMenuHighlightMode = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "MenuHighlightMode" ), mMenuHighlightMode, valuesMenuHighlightMode, MM_DARK );
  addItem( itemMenuHighlightMode, QStringLiteral( "MenuHighlightMode" ) );
  KConfigSkeleton::ItemBool  *itemWindowDragEnabled;
  itemWindowDragEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "WindowDragEnabled" ), mWindowDragEnabled, true );
  addItem( itemWindowDragEnabled, QStringLiteral( "WindowDragEnabled" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesWindowDragMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("WD_NONE");
    valuesWindowDragMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("WD_MINIMAL");
    valuesWindowDragMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("WD_FULL");
    valuesWindowDragMode.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemWindowDragMode;
  itemWindowDragMode = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "WindowDragMode" ), mWindowDragMode, valuesWindowDragMode, WD_FULL );
  addItem( itemWindowDragMode, QStringLiteral( "WindowDragMode" ) );
  KConfigSkeleton::ItemBool  *itemSplitterProxyEnabled;
  itemSplitterProxyEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SplitterProxyEnabled" ), mSplitterProxyEnabled, true );
  addItem( itemSplitterProxyEnabled, QStringLiteral( "SplitterProxyEnabled" ) );
  KConfigSkeleton::ItemInt  *itemSplitterProxyWidth;
  itemSplitterProxyWidth = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "SplitterProxyWidth" ), mSplitterProxyWidth, 12 );
  addItem( itemSplitterProxyWidth, QStringLiteral( "SplitterProxyWidth" ) );
  KConfigSkeleton::ItemBool  *itemWidgetExplorerEnabled;
  itemWidgetExplorerEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "WidgetExplorerEnabled" ), mWidgetExplorerEnabled, false );
  addItem( itemWidgetExplorerEnabled, QStringLiteral( "WidgetExplorerEnabled" ) );
  KConfigSkeleton::ItemBool  *itemDrawWidgetRects;
  itemDrawWidgetRects = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "DrawWidgetRects" ), mDrawWidgetRects, false );
  addItem( itemDrawWidgetRects, QStringLiteral( "DrawWidgetRects" ) );
  KConfigSkeleton::ItemStringList  *itemWindowDragWhiteList;
  itemWindowDragWhiteList = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "WindowDragWhiteList" ), mWindowDragWhiteList );
  addItem( itemWindowDragWhiteList, QStringLiteral( "WindowDragWhiteList" ) );
  KConfigSkeleton::ItemStringList  *itemWindowDragBlackList;
  itemWindowDragBlackList = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "WindowDragBlackList" ), mWindowDragBlackList );
  addItem( itemWindowDragBlackList, QStringLiteral( "WindowDragBlackList" ) );
  KConfigSkeleton::ItemBool  *itemUseWMMoveResize;
  itemUseWMMoveResize = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseWMMoveResize" ), mUseWMMoveResize, true );
  addItem( itemUseWMMoveResize, QStringLiteral( "UseWMMoveResize" ) );
  KConfigSkeleton::ItemBool  *itemAnimationsEnabled;
  itemAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AnimationsEnabled" ), mAnimationsEnabled, true );
  addItem( itemAnimationsEnabled, QStringLiteral( "AnimationsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemGenericAnimationsEnabled;
  itemGenericAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GenericAnimationsEnabled" ), mGenericAnimationsEnabled, true );
  addItem( itemGenericAnimationsEnabled, QStringLiteral( "GenericAnimationsEnabled" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesToolBarAnimationType;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TB_NONE");
    valuesToolBarAnimationType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TB_FADE");
    valuesToolBarAnimationType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TB_FOLLOW_MOUSE");
    valuesToolBarAnimationType.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemToolBarAnimationType;
  itemToolBarAnimationType = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "ToolBarAnimationType" ), mToolBarAnimationType, valuesToolBarAnimationType, TB_FADE );
  addItem( itemToolBarAnimationType, QStringLiteral( "ToolBarAnimationType" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesMenuBarAnimationType;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MB_NONE");
    valuesMenuBarAnimationType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MB_FADE");
    valuesMenuBarAnimationType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MB_FOLLOW_MOUSE");
    valuesMenuBarAnimationType.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemMenuBarAnimationType;
  itemMenuBarAnimationType = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "MenuBarAnimationType" ), mMenuBarAnimationType, valuesMenuBarAnimationType, MB_FADE );
  addItem( itemMenuBarAnimationType, QStringLiteral( "MenuBarAnimationType" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesMenuAnimationType;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ME_NONE");
    valuesMenuAnimationType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ME_FADE");
    valuesMenuAnimationType.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ME_FOLLOW_MOUSE");
    valuesMenuAnimationType.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemMenuAnimationType;
  itemMenuAnimationType = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "MenuAnimationType" ), mMenuAnimationType, valuesMenuAnimationType, ME_FADE );
  addItem( itemMenuAnimationType, QStringLiteral( "MenuAnimationType" ) );
  KConfigSkeleton::ItemBool  *itemProgressBarAnimationsEnabled;
  itemProgressBarAnimationsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ProgressBarAnimationsEnabled" ), mProgressBarAnimationsEnabled, true );
  addItem( itemProgressBarAnimationsEnabled, QStringLiteral( "ProgressBarAnimationsEnabled" ) );
  KConfigSkeleton::ItemInt  *itemGenericAnimationsDuration;
  itemGenericAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "GenericAnimationsDuration" ), mGenericAnimationsDuration, 150 );
  addItem( itemGenericAnimationsDuration, QStringLiteral( "GenericAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemToolBarAnimationsDuration;
  itemToolBarAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ToolBarAnimationsDuration" ), mToolBarAnimationsDuration, 50 );
  addItem( itemToolBarAnimationsDuration, QStringLiteral( "ToolBarAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemMenuBarAnimationsDuration;
  itemMenuBarAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MenuBarAnimationsDuration" ), mMenuBarAnimationsDuration, 150 );
  addItem( itemMenuBarAnimationsDuration, QStringLiteral( "MenuBarAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemMenuBarFollowMouseAnimationsDuration;
  itemMenuBarFollowMouseAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MenuBarFollowMouseAnimationsDuration" ), mMenuBarFollowMouseAnimationsDuration, 80 );
  addItem( itemMenuBarFollowMouseAnimationsDuration, QStringLiteral( "MenuBarFollowMouseAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemMenuAnimationsDuration;
  itemMenuAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MenuAnimationsDuration" ), mMenuAnimationsDuration, 150 );
  addItem( itemMenuAnimationsDuration, QStringLiteral( "MenuAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemMenuFollowMouseAnimationsDuration;
  itemMenuFollowMouseAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "MenuFollowMouseAnimationsDuration" ), mMenuFollowMouseAnimationsDuration, 40 );
  addItem( itemMenuFollowMouseAnimationsDuration, QStringLiteral( "MenuFollowMouseAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemProgressBarAnimationsDuration;
  itemProgressBarAnimationsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ProgressBarAnimationsDuration" ), mProgressBarAnimationsDuration, 250 );
  addItem( itemProgressBarAnimationsDuration, QStringLiteral( "ProgressBarAnimationsDuration" ) );
  KConfigSkeleton::ItemInt  *itemProgressBarBusyStepDuration;
  itemProgressBarBusyStepDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ProgressBarBusyStepDuration" ), mProgressBarBusyStepDuration, 50 );
  addItem( itemProgressBarBusyStepDuration, QStringLiteral( "ProgressBarBusyStepDuration" ) );
  KConfigSkeleton::ItemBool  *itemStackedWidgetTransitionsEnabled;
  itemStackedWidgetTransitionsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "StackedWidgetTransitionsEnabled" ), mStackedWidgetTransitionsEnabled, false );
  addItem( itemStackedWidgetTransitionsEnabled, QStringLiteral( "StackedWidgetTransitionsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemLabelTransitionsEnabled;
  itemLabelTransitionsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LabelTransitionsEnabled" ), mLabelTransitionsEnabled, true );
  addItem( itemLabelTransitionsEnabled, QStringLiteral( "LabelTransitionsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemComboBoxTransitionsEnabled;
  itemComboBoxTransitionsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ComboBoxTransitionsEnabled" ), mComboBoxTransitionsEnabled, true );
  addItem( itemComboBoxTransitionsEnabled, QStringLiteral( "ComboBoxTransitionsEnabled" ) );
  KConfigSkeleton::ItemBool  *itemLineEditTransitionsEnabled;
  itemLineEditTransitionsEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LineEditTransitionsEnabled" ), mLineEditTransitionsEnabled, true );
  addItem( itemLineEditTransitionsEnabled, QStringLiteral( "LineEditTransitionsEnabled" ) );
  KConfigSkeleton::ItemInt  *itemStackedWidgetTransitionsDuration;
  itemStackedWidgetTransitionsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "StackedWidgetTransitionsDuration" ), mStackedWidgetTransitionsDuration, 150 );
  addItem( itemStackedWidgetTransitionsDuration, QStringLiteral( "StackedWidgetTransitionsDuration" ) );
  KConfigSkeleton::ItemInt  *itemLabelTransitionsDuration;
  itemLabelTransitionsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "LabelTransitionsDuration" ), mLabelTransitionsDuration, 75 );
  addItem( itemLabelTransitionsDuration, QStringLiteral( "LabelTransitionsDuration" ) );
  KConfigSkeleton::ItemInt  *itemComboBoxTransitionsDuration;
  itemComboBoxTransitionsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ComboBoxTransitionsDuration" ), mComboBoxTransitionsDuration, 75 );
  addItem( itemComboBoxTransitionsDuration, QStringLiteral( "ComboBoxTransitionsDuration" ) );
  KConfigSkeleton::ItemInt  *itemLineEditTransitionsDuration;
  itemLineEditTransitionsDuration = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "LineEditTransitionsDuration" ), mLineEditTransitionsDuration, 150 );
  addItem( itemLineEditTransitionsDuration, QStringLiteral( "LineEditTransitionsDuration" ) );
}

StyleConfigData::~StyleConfigData()
{
  if (s_globalStyleConfigData.exists() && !s_globalStyleConfigData.isDestroyed()) {
    s_globalStyleConfigData()->q = nullptr;
  }
}

