#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'oxygenmdidemowidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.18
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OXYGENMDIDEMOWIDGET_H
#define UI_OXYGENMDIDEMOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMdiArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_MdiDemoWidget
{
public:
    QVBoxLayout *verticalLayout;
    QMdiArea *mdiArea;
    QWidget *Editors;
    QGridLayout *gridLayout;
    QLabel *label;
    KLineEdit *lineEdit;
    QTextEdit *textEdit;
    QWidget *Toolbox;
    QVBoxLayout *verticalLayout_2;
    QToolBox *toolBox;
    QWidget *page;
    QVBoxLayout *verticalLayout_4;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_2;
    QLabel *label_3;
    QSpacerItem *verticalSpacer;
    QWidget *page_3;

    void setupUi(QWidget *MdiDemoWidget)
    {
        if (MdiDemoWidget->objectName().isEmpty())
            MdiDemoWidget->setObjectName(QString::fromUtf8("MdiDemoWidget"));
        MdiDemoWidget->resize(620, 420);
        verticalLayout = new QVBoxLayout(MdiDemoWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        mdiArea = new QMdiArea(MdiDemoWidget);
        mdiArea->setObjectName(QString::fromUtf8("mdiArea"));
        mdiArea->setLineWidth(0);
        mdiArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        mdiArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        Editors = new QWidget();
        Editors->setObjectName(QString::fromUtf8("Editors"));
        Editors->setMinimumSize(QSize(300, 100));
        gridLayout = new QGridLayout(Editors);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(Editors);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        lineEdit = new KLineEdit(Editors);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setProperty("showClearButton", QVariant(true));

        gridLayout->addWidget(lineEdit, 0, 1, 1, 1);

        textEdit = new QTextEdit(Editors);
        textEdit->setObjectName(QString::fromUtf8("textEdit"));

        gridLayout->addWidget(textEdit, 1, 0, 1, 2);

        mdiArea->addSubWindow(Editors);
        Toolbox = new QWidget();
        Toolbox->setObjectName(QString::fromUtf8("Toolbox"));
        Toolbox->setMinimumSize(QSize(300, 100));
        verticalLayout_2 = new QVBoxLayout(Toolbox);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        toolBox = new QToolBox(Toolbox);
        toolBox->setObjectName(QString::fromUtf8("toolBox"));
        page = new QWidget();
        page->setObjectName(QString::fromUtf8("page"));
        page->setGeometry(QRect(0, 0, 282, 72));
        verticalLayout_4 = new QVBoxLayout(page);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        toolBox->addItem(page, QString::fromUtf8("First Page"));
        page_2 = new QWidget();
        page_2->setObjectName(QString::fromUtf8("page_2"));
        page_2->setGeometry(QRect(0, 0, 83, 40));
        verticalLayout_3 = new QVBoxLayout(page_2);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        label_2 = new QLabel(page_2);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        verticalLayout_3->addWidget(label_2);

        label_3 = new QLabel(page_2);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        verticalLayout_3->addWidget(label_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        toolBox->addItem(page_2, QString::fromUtf8("Second Page"));
        page_3 = new QWidget();
        page_3->setObjectName(QString::fromUtf8("page_3"));
        page_3->setGeometry(QRect(0, 0, 100, 30));
        toolBox->addItem(page_3, QString::fromUtf8("Third Page"));

        verticalLayout_2->addWidget(toolBox);

        mdiArea->addSubWindow(Toolbox);

        verticalLayout->addWidget(mdiArea);


        retranslateUi(MdiDemoWidget);

        toolBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MdiDemoWidget);
    } // setupUi

    void retranslateUi(QWidget *MdiDemoWidget)
    {
        Editors->setWindowTitle(tr2i18n("Editors", nullptr));
        label->setText(tr2i18n("Title:", nullptr));
        Toolbox->setWindowTitle(tr2i18n("Toolbox", nullptr));
        toolBox->setItemText(toolBox->indexOf(page), tr2i18n("First Page", nullptr));
        label_2->setText(tr2i18n("First Label", nullptr));
        label_3->setText(tr2i18n("Second Label", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_2), tr2i18n("Second Page", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_3), tr2i18n("Third Page", nullptr));
        (void)MdiDemoWidget;
    } // retranslateUi

};

namespace Ui {
    class MdiDemoWidget: public Ui_MdiDemoWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OXYGENMDIDEMOWIDGET_H

